<?php
class RADIO_CLASS {
	public $page_title;
	public $page_description;
	public $page_image;
	public $page_url;
	public $rewriterule_allow = false;

	public $current_page_protocol;
	public $current_page_site;
	public $current_page_thisfile;
	public $current_page_real_directories;
	public $current_page_num_of_real_directories;
	public $current_page_virtual_directories = [];
	public $current_page_num_of_virtual_directories = [];
	public $current_page_baseurl;
	public $current_page_thisurl;

	public $current_url;
	public $_url;
	public $_p1;
	public $_p2;
	public $_p3;
	public $_p4;
	public $_params;
	public $_breadcrumb;
	public $top_breadcrumb = true;
	public $hide_breadcrumb = false;
	public $link_type = 'modal';
	public $show_quick_links = true;

	public function __construct(){
		$this->current_page_protocol = ( isset($_SERVER['HTTPS']) ? 'https' : 'http' );
		$this->current_page_site = $this->current_page_protocol . '://' . $_SERVER['HTTP_HOST'];
		$this->current_page_thisfile = basename($_SERVER['SCRIPT_FILENAME']);
		$this->current_page_real_directories = $this->cleanUp(explode("/", str_replace($this->current_page_thisfile, "", $_SERVER['PHP_SELF'])));
		$this->current_page_num_of_real_directories = count($this->current_page_real_directories);
		$this->current_page_virtual_directories = array_diff($this->cleanUp(explode("/", str_replace($this->current_page_thisfile, "", $_SERVER['REQUEST_URI']))),$this->current_page_real_directories);
		$this->current_page_num_of_virtual_directories = count($this->current_page_virtual_directories);
		$this->current_page_baseurl = $this->current_page_site . "/" . implode("/", $this->current_page_real_directories) . "/";
		$this->current_page_thisurl = $this->current_page_baseurl . implode("/", $this->current_page_virtual_directories) . "";

		$current_url = str_replace($this->current_page_baseurl, '', $this->current_page_thisurl);
		$url = trim( $current_url, '/' );

		$this->current_url = $url;
    $url_explode = explode('/', $url, 4);

    if( isset($url_explode[0]) && !empty($url_explode[0]) ){
      $this->_p1 = $url_explode[0];
    }
    if( isset($url_explode[1]) && !empty($url_explode[1]) ){
      $this->_p2 = $this->slug_decoding($url_explode[1]);
    }
    if( isset($url_explode[2]) && !empty($url_explode[2]) ){
      $this->_p3 = $this->slug_decoding($url_explode[2]);
    }
		if( isset($url_explode[3]) && !empty($url_explode[3]) ){
      $this->_p4 = $this->slug_decoding($url_explode[3]);
    }
    if( isset($url_explode[4]) && !empty($url_explode[4]) ){
			$params = explode('/', trim($url_explode[4]));
			$this->_params = $params;
    }
	}

	public function cleanUp($array){
		$cleaned_array = array();
		foreach($array as $key => $value){
			$qpos = strpos($value, "?");
			if($qpos !== false){ break; }
				if($key != "" && $value != ""){ $cleaned_array[] = $value; }
		}
		return $cleaned_array;
	}

	public function slug_decoding($text){
		return urldecode($text);
	}

	public function baseurl_data(){
		$protocol = ( isset($_SERVER['HTTPS']) ? 'https' : 'http' );
		$site = $protocol . '://' . $_SERVER['HTTP_HOST'];
		$thisfile = basename($_SERVER['SCRIPT_FILENAME']);
		$real_directories = $this->cleanUp(explode("/", str_replace($thisfile, "", $_SERVER['PHP_SELF'])));
		$num_of_real_directories = count($real_directories);
		$virtual_directories = array_diff($this->cleanUp(explode("/", str_replace($thisfile, "", $_SERVER['REQUEST_URI']))), $real_directories);
		$num_of_virtual_directories = count($virtual_directories);
		$baseurl = $site . "/" . implode("/", $real_directories) . "/";
		$thisurl = $baseurl . implode("/", $virtual_directories) . "";

		$url = array(
			'protocol' => $protocol,
			'site' => $site,
			'thisfile' => $thisfile,
			'real_directories' => $real_directories,
			'virtual_directories' => $virtual_directories,
			'baseurl' => $baseurl,
			'thisurl' => $thisurl
		);

		return $url;
	}

	public function baseurl( $url = '' ){
		$baseurl = $this->baseurl_data();
		$site_url = rtrim($baseurl['baseurl'], '/');
		return $site_url.'/'.$url;
	}

	public function url( $url = '' ){
		$rewriterule_allow = $this->rewriterule_allow;
		if( $rewriterule_allow ){
			return $this->baseurl( $url );
		}else{
			$split = explode('/', $url);
			$createLink = '';
			if( isset($split[0]) && !empty($split[0]) ){
				$createLink .= '?action='.strip_tags($split[0]);
			}
			if( !empty($createLink) ){
				if( isset($split[1]) && !empty($split[1]) ){
					$createLink .= '&page_id='.strip_tags($split[1]);
				}
				if( isset($split[2]) && !empty($split[2]) ){
					$createLink .= '&surah_id='.strip_tags($split[2]);
				}
				if( isset($split[3]) && !empty($split[3]) ){
					$createLink .= '&ayah_id='.strip_tags($split[3]);
				}
			}
			return $this->baseurl( $createLink );
		}
	}

	public function current_lang() {
		$getLang = ( isset($_GET['lang']) && $_GET['lang'] == 'en' ? 'en' : 'ar' );
		if( isset($_SESSION['lang']) && !empty($_SESSION['lang']) ){
			if( isset($_GET['lang']) && !empty($_GET['lang']) ){
				$_SESSION['lang'] = strip_tags($_GET['lang']);
				$getLang = $_SESSION['lang'];
			}else{
				$getLang = $_SESSION['lang'];
			}
		}else{
			$_SESSION['lang'] = $getLang;
		}

		return $getLang;
	}

	public function lang($k) {
		global $lang;
		if( $this->current_lang() == 'en' ){
			include_once(RADIO_ROOT.'/language/en.php');
		}else{
			include_once(RADIO_ROOT.'/language/ar.php');
		}
		return ( isset($lang[$k]) ? $lang[$k] : 'Not found key ['.$k.']' );
	}

	public function get_flags(){
		$lang = $this->current_lang();
		$langs = [
			'ar' => $this->lang('arabic'),
			'en' => $this->lang('english')
		];
		$html = '<div class="flags">';
		foreach ($langs as $key => $value) {
			if( $key == $lang ){
				$html .= '<img src="'.$this->baseurl('images/'.$key.'.png').'" alt="'.$value.'" title="'.$value.'">';
			}else{
				$html .= '<a href="'.$this->baseurl('?lang='.$key).'"><img src="'.$this->baseurl('images/'.$key.'.png').'" alt="'.$value.'" title="'.$value.'"></a>';
			}
		}
		$html .= '</div>';
	  return $html;
	}

	public function breadcrumb($title, $args=[]){
		if( $this->hide_breadcrumb ){
			return '';
		}

		if( $this->top_breadcrumb ){
			$class = 'breadcrumb-container breadcrumb-container-top';
		}else{
			$class = 'breadcrumb-container';
		}
		$html = '<nav aria-label="breadcrumb" class="'.$class.'">';
		$html .= '<ol class="breadcrumb">';
		$html .= '<li class="breadcrumb-item"><a href="'.$this->url().'">'.$this->lang('home').'</a></li>';
		if( is_array($args) && count($args) > 0 ){
			foreach ($args as $k => $v) {
				$html .= '<li class="breadcrumb-item"><a href="'.$v['url'].'">'.$v['name'].'</a></li>';
			}
		}
		$html .= '<li class="breadcrumb-item active" aria-current="page">'.$title.'</li>';
		$html .= '</ol>';
		$html .= '</nav>';
		return $html;
	}

	public function get_radio( $id, $radios, $arr = false ){
		if( isset($radios[$id]) && is_array($radios[$id]) ){
			$v = $radios[$id];
			$title = ( isset($v['title']) ? $v['title'] : '' );
			$title_ar = ( isset($v['title_ar']) ? $v['title_ar'] : '' );
			$book = ( isset($v['book']) ? $v['book'] : '' );
			$rss = ( isset($v['rss']) ? $v['rss'] : '' );
			$podcast = ( isset($v['podcast']) ? $v['podcast'] : '' );
			$google_podcast = ( isset($v['google_podcast']) ? $v['google_podcast'] : '' );
			$txt = ( isset($v['txt']) ? $v['txt'] : '' );
			$asx = ( isset($v['asx']) ? $v['asx'] : '' );
			$qtl = ( isset($v['qtl']) ? $v['qtl'] : '' );
			$ram = ( isset($v['ram']) ? $v['ram'] : '' );
			$pls = ( isset($v['pls']) ? $v['pls'] : '' );
			$port = ( isset($v['port']) ? $v['port'] : '' );
			$server = ( isset($v['server']) ? $v['server'] : '' );
			$radio = ( isset($v['radio']) ? $v['radio'] : '' );
			$tunein = ( isset($v['tunein']) ? $v['tunein'] : '' );
			$url = ( isset($v['url']) ? $v['url'] : '' );
			$soundcloud = ( isset($v['soundcloud']) ? $v['soundcloud'] : '' );
			$twitter = ( isset($v['twitter']) ? $v['twitter'] : '' );

			if( $this->current_lang() == 'en' ){
				$title_ar = $title;
			}

			if( $arr ){
				return [
					'title' => $title_ar,
					'book' => $book,
					'rss' => $rss,
					'podcast' => $podcast,
					'google_podcast' => $google_podcast,
					'txt' => $txt,
					'asx' => $asx,
					'qtl' => $qtl,
					'ram' => $ram,
					'pls' => $pls,
					'port' => $port,
					'server' => $server,
					'radio' => $radio,
					'tunein' => $tunein,
					'url' => $url,
					'soundcloud' => $soundcloud,
					'twitter' => $twitter
				];
			}

			if( $this->link_type == 'modal' ){
				$radio_link = '';
				$attr = ' data-bs-toggle="modal" data-bs-target="#modalRadio"';
			}else{
				$attr = '';
				$radio_link = $this->url('page/'.$id);
			}

			$getIcons = $this->radio_icons($v);

			$html = '<div class="radio-info" id="radio-'.$id.'" data-name="'.$title_ar.'" data-port="'.$port.'" data-server="'.$server.'">';
			$html .= '<div class="radio-icons" style="display: none;">'.$getIcons.'</div>';
			$html .= '<div class="radio-image"'.$attr.'>';
			if( !empty($radio_link) ){
				$html .= '<a href="'.$radio_link.'">';
			}
			$html .= '<img src="'.$this->baseurl('images/radio/'.$id.'.jpg').'" alt="'.$title_ar.'" class="rounded-circle mw-100 mb-3" loading="lazy">';
			if( !empty($radio_link) ){
				$html .= '</a>';
			}
			$html .= '</div>';

			$html .= '<p>';
			$html .= '<a href="'.$this->url('page/'.$id).'">';
			$html .= $title_ar;
			$html .= '</a>';
			$html .= '</p>';
			$html .= '</div>';

			return $html;
		}else{
			return false;
		}
	}

	public function radio_icons($radio) {
		// 'asx' => $asx,
		// 'qtl' => $qtl,
		// 'ram' => $ram,
		// 'pls' => $pls,
		// 'radio' => $radio,
		// 'url' => $url,

		$icons = '';
		if( !empty($radio['book']) ){
			$icons .= '<a target="_blank" href="'.$radio['book'].'"><i class="fa-solid fa-book"></i></a>';
		}
		if( !empty($radio['rss']) ){
			$icons .= '<a target="_blank" href="'.$radio['rss'].'"><i class="fa-solid fa-rss"></i></a>';
		}
		if( !empty($radio['podcast']) ){
			$icons .= '<a target="_blank" href="'.$radio['podcast'].'"><i class="fa-brands fa-apple"></i></a>';
		}
		if( !empty($radio['google_podcast']) ){
			$icons .= '<a target="_blank" href="'.$radio['google_podcast'].'"><i class="fa-brands fa-google"></i></a>';
		}
		if( !empty($radio['soundcloud']) ){
			$icons .= '<a target="_blank" href="'.$radio['soundcloud'].'"><i class="fa-brands fa-soundcloud"></i></a>';
		}
		if( !empty($radio['tunein']) ){
			$icons .= '<a target="_blank" href="'.$radio['tunein'].'"><i class="fa-solid fa-microphone"></i></a>';
		}
		if( !empty($radio['txt']) ){
			$icons .= '<a target="_blank" href="'.$radio['txt'].'"><i class="fa-solid fa-download"></i></a>';
		}
		if( !empty($radio['twitter']) ){
			$icons .= '<a target="_blank" href="'.$radio['twitter'].'"><i class="fab fa-twitter"></i></a>';
		}
		if( !empty($radio['facebook']) ){
			$icons .= '<a target="_blank" href="'.$radio['facebook'].'"><i class="fab fa-facebook"></i></a>';
		}

		$getIcons = '';
		if( !empty($icons) ){
			$getIcons .= '<div class="radio-icons">';
			$getIcons .= $icons;
			$getIcons .= '</div>';
		}

		return $getIcons;
	}

	public function output_single_radio( $radio_id = 1 ){
		$radios = $this->radios();

		if( !empty($radio_id) && isset($radios[$radio_id]) ){

			$radio = $this->get_radio( $radio_id, $radios, true );

			$this->page_title = $radio['title'];
			$this->page_description = $radio['title'];
			$this->page_image = $this->baseurl('images/radio/'.$radio_id.'.jpg');
			$this->page_url = $this->url('page/'.$radio_id);

			$html = '';
			$breadcrumb = $this->breadcrumb( $this->page_title );
			$this->_breadcrumb = $breadcrumb;
			if( !$this->top_breadcrumb ){
				$html .= $breadcrumb;
			}

			$radioURL = $radio['server'].':'.$radio['port'].'/;*.mp3';

			$getIcons = $this->radio_icons($radio);

			$html .= '<div class="radio-container">';
			$html .= '<div class="container">';
			$html .= '<div class="radio-title">';
			$html .= '<h1>'.$radio['title'].'</h1>';
			$html .= '</div>';

			$html .= '<div class="row g-3">';
			$html .= '<div class="col-4 col-md-2">';
			$html .= '<div class="radio-image">';
			$html .= '<img src="'.$this->baseurl('images/radio/'.$radio_id.'.jpg').'" alt="'.$radio['title'].'" class="w-100" loading="lazy">';
			$html .= '</div>';
			$html .= '</div>';
			$html .= '<div class="col-8 col-md-10">';
			$html .= $this->play_audio($radioURL);
			$html .= $getIcons;
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';

			$html .= $this->share($this->page_title, $this->page_url);
			$html .= '</div>';
		}else{
			header("HTTP/1.0 404 Not Found");
			$html = '<div class="error-container">';
			$html .= '<div class="container">';
			$html .= '<div class="alert alert-danger">';
			$html .= '<p class="mb-0">'.$this->lang('not_found').'</p>';
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
		}

		return $html;
	}

	public function output_radios(){
		$radios = $this->radios();

		$html = '<div class="radio-container">';
		$html .= '<div id="radio-categories" class="radio-categories">';
		$i=0;
		foreach ($this->radio_cargories() as $key => $value) {
			$i++;
			$addClass = ( $i > 1 ? 'radio-category radio-category-'.$key : 'radio-category radio-category-'.$key );

			$x = ($i % 2);
			if( $x == 1 ){
				$addClass .= ' white';
			}else{
				$addClass .= ' gray';
			}

			$html .= '<div id="'.$key.'" class="'.$addClass.'">';
			$html .= '<div class="container">';
			$html .= '<div class="radio-category-title">';
			$html .= '<h1><a href="'.$this->url('category/'.$key).'">'.$this->lang($key).'</a></h1>';
			$html .= '</div>';
			if( is_array($value) && count($value) > 0 ){
				$html .= '<div class="row g-3">';
				foreach ($value as $keyx => $valuex) {
					$html .= '<div class="col-6 col-md-3">';
					$html .= $this->get_radio( $valuex, $radios );
					$html .= '</div>';
				}
				$html .= '</div>';
			}
			$html .= '</div>';
			$html .= '</div>';
		}
		$html .= '</div>';
		$html .= $this->share($this->page_title, $this->page_url);
		$html .= '</div>';


		return $html;
	}

	public function output_category( $id ){
		$radios = $this->radios();
		$cargories = $this->radio_cargories();

		if( isset($cargories[$id]) && is_array($cargories[$id]) ){
			$value = $cargories[$id];

			$this->page_title = $this->lang('title').' - '.$this->lang($id);
			$this->page_description = $this->lang('title').' - '.$this->lang($id);
			$this->page_url = $this->url('category/'.$id);

			$html = '';
			$breadcrumb = $this->breadcrumb( $this->lang($id) );
			$this->_breadcrumb = $breadcrumb;
			if( !$this->top_breadcrumb ){
				$html .= $breadcrumb;
			}

			$html = '<div class="radio-container">';
			$html .= '<div id="radio-categories" class="radio-categories">';
			$html .= '<div id="'.$id.'" class="radio-category radio-category-'.$id.'">';
			$html .= '<div class="container">';
			$html .= '<div class="radio-category-title">';
			$html .= '<h1>'.$this->lang($id).'</h1>';
			$html .= '</div>';
			if( is_array($value) && count($value) > 0 ){
				$html .= '<div class="row g-3">';
				foreach ($value as $keyx => $valuex) {
					$html .= '<div class="col-6 col-md-3">';
					$html .= $this->get_radio( $valuex, $radios );
					$html .= '</div>';
				}
				$html .= '</div>';
			}
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
			$html .= $this->share($this->page_title, $this->page_url);
			$html .= '</div>';
		}else{
			header("HTTP/1.0 404 Not Found");
			$html = '<div class="error-container">';
			$html .= '<div class="container">';
			$html .= '<div class="alert alert-danger">';
			$html .= '<p class="mb-0">'.$this->lang('not_found').'</p>';
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
		}

		return $html;
	}

	public function share($title, $url){

		$social = array(
			'facebook' => array( 'title' => 'Facebook', 'icon' => 'fab fa-facebook' ),
			'twitter' => array( 'title' => 'Twitter', 'icon' => 'fab fa-twitter' ),
			'whatsapp' => array( 'title' => 'WhatsApp', 'icon' => 'fab fa-whatsapp' ),
			'pinterest' => array( 'title' => 'Pinterest', 'icon' => 'fab fa-pinterest' ),
			'linkedIn' => array( 'title' => 'LinkedIn', 'icon' => 'fab fa-linkedin' ),
			'buffer' => array( 'title' => 'Buffer', 'icon' => 'fab fa-buffer' ),
			'tumblr' => array( 'title' => 'Tumblr', 'icon' => 'fab fa-tumblr' ),
			'reddit' => array( 'title' => 'Reddit', 'icon' => 'fab fa-reddit' ),
			'mix' => array( 'title' => 'Mix', 'icon' => 'fab fa-mix' ),
			'evernote' => array( 'title' => 'Evernote', 'icon' => 'fab fa-evernote' ),
			'pocket' => array( 'title' => 'Pocket', 'icon' => 'fab fa-get-pocket' ),
			'wordpress' => array( 'title' => 'Wordpress', 'icon' => 'fab fa-wordpress' )
		);

		$html = '<div class="radio-share">';
		foreach( $social as $key => $value ){
			$html .= '<button class="quran-social btn btn-secondary btn-sm" data-type="'.$key.'" data-url="'.$url.'" title="'.$title.'">';
			$html .= '<i class="'.$value['icon'].'"></i> '.$value['title'];
			$html .= '</button> ';
		}
		$html .= '</div>';
		return $html;
	}

	public function action() {
		$action = ( isset($_GET['action']) ? strip_tags($_GET['action']) : $this->_p1 );
		return $action;
	}

	public function radio_id() {
		$radio_id = ( isset($_GET['radio_id']) ? intval($_GET['radio_id']) : $this->_p2 );
		return $radio_id;
	}

	public function category_id() {
		$category_id = ( isset($_GET['category_id']) ? strip_tags($_GET['category_id']) : $this->_p2 );
		return $category_id;
	}

	public function output() {
		$action = $this->action();

		$this->page_title = $this->lang('title');
		$this->page_description = $this->lang('description');
		$this->page_image = $this->baseurl('images/og.jpg');
		$this->page_url = $this->url();

		if( $action == 'page' ){
			$radio_id = $this->radio_id();
			$html = $this->output_single_radio($radio_id);
		}elseif( $action == 'category' ){
			$category_id = $this->category_id();
			$html = $this->output_category($category_id);
		}else{
			$html = $this->output_radios();
		}

		return $html;
	}

	public function radio_cargories(){

		$radios = [
			'arabic_recitations' => [39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 53, 54, 60, 61, 62, 63, 64, 65, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 111, 112, 113, 114, 115, 121, 125, 126, 127],
			'qiraat' => [80, 88, 83, 85, 82, 92, 90, 91, 89, 87, 86, 58, 84, 98, 57, 93, 95, 97, 96, 94, 59, 56, 55, 52, 79],
			'fatwas_and_tafsir' => [64, 68, 38, 122, 120, 127, 66, 36, 63, 81, 44],
			'quranic_sciences' => [116, 117, 118, 119, 120],
			'western_translations' => [1, 2, 3, 4, 5, 6, 13, 14, 19, 20, 35, 68, 109, 110, 123, 124, 128, 129, 130, 131],
			'asian' => [7, 8, 9, 10, 12, 15, 17, 18, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 33, 34, 67, 132],
			'african' => [11, 16, 31, 32, 36, 37, 66, 81],
			'almushaf_almuallim' => [128, 129, 130, 131]
		];

		return $radios;
	}

	public function radios(){
		$site = 'https://www.qurantranslations.net';
		$server = 'https://server03.quran-uni.com';
		$radios = [
			1 => [
				'title' => 'Translation of the Quran in English',
				'title_ar' => 'ترجمة القرآن الكريم بالإنجليزية',
				'book' => $site.'/quran/pdf/en_Translation_of_the_Meanings_Quran.pdf',
				'rss' => $site.'/podcast/English/Mishary__Al-Afasy.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/recitation-by-abdulbaset-abdul/id878595831',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjk5OTAvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/English/Mishary_Al-Afasy.txt',
				'asx' => $site.'/radio/7050/MediaPlayer.asx',
				'qtl' => $site.'/radio/7050/QuickTime.qtl',
				'ram' => $site.'/radio/7050/RealPlayer.ram',
				'pls' => $site.'/radio/7050/Winamp.pls',
				'port' => '7050',
				'server' => $server,
				'radio' => $server.':7050',
				'tunein' => 'http://tunein.com/radio/Quran-in-English-s191103/',
				'url' => $site.'/index.php?moshaf=8&id=8',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_english	',
				'twitter' => 'https://twitter.com/QuraninEng'
			],
			2 => [
				'title' => 'Translation of the Quran in German',
				'title_ar' => 'ترجمة القرآن الكريم بالألمانية',
				'book' => $site.'/quran/pdf/de_translation_of_the_meaning_of_the_holy_quran_in_deutsch.pdf',
				'rss' => $site.'/podcast/Deutsch/deutsch.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id878103346',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3F1cmFhbi51czo5OTg2LzsqLm1wMw?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Deutsch/deutsch.txt',
				'asx' => $site.'/radio/7043/MediaPlayer.asx',
				'qtl' => $site.'/radio/7043/QuickTime.qtl',
				'ram' => $site.'/radio/7043/RealPlayer.ram',
				'pls' => $site.'/radio/7043/Winamp.pls',
				'port' => '7043',
				'server' => $server,
				'radio' => $server.':7043',
				'tunein' => 'http://tunein.com/radio/Koran-Auf-Deutsch-von-EDC-s190967/',
				'url' => $site.'/index.php?moshaf=1&id=1',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_german',
				'twitter' => 'https://twitter.com/KoranAufDeutsch'
			],
			3 => [
				'title' => 'Translation of the Quran in Bosnian',
				'title_ar' => 'ترجمة القرآن الكريم بالرومانية',
				'book' => $site.'/quran/pdf/bs_Prevod_Kuran_na_bos.pdf',
				'rss' => $site.'/podcast/Bosnian/Mahmoud_Khalil_Al-Husari.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/recitation-by-mahmoud-khalil/id878087243',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjk5OTQvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Bosnian/Mahmoud_Khalil_Al-Husari.txt',
				'asx' => $site.'/radio/bosquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/bosquraa/QuickTime.qtl',
				'ram' => $site.'/radio/bosquraa/RealPlayer.ram',
				'pls' => $site.'/radio/bosquraa/Winamp.pls',
				'port' => '7013',
				'server' => $server,
				'radio' => $server.':7013',
				'tunein' => 'http://tunein.com/radio/Quran-in-Bosnian-s191065/',
				'url' => $site.'/index.php?moshaf=23&id=7',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_quran_in_bosnian'
			],
			4 => [
				'title' => 'Translation of the Quran in Spanish',
				'title_ar' => 'ترجمة القرآن الكريم بالإسبانية',
				'book' => $site.'/quran/pdf/es_The_Quran_Nobleman.pdf',
				'rss' => $site.'/podcast/Spanish/Abu-Mujahid.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558770',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3F1cmFhbi51czo5OTYwLzsqLm1wMw?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Spanish/Abu-Mujahid.txt',
				'asx' => $site.'/radio/esquraan/MediaPlayer.asx',
				'qtl' => $site.'/radio/esquraan/QuickTime.qtl',
				'ram' => $site.'/radio/esquraan/RealPlayer.ram',
				'pls' => $site.'/radio/esquraan/Winamp.pls',
				'port' => '7003',
				'server' => $server,
				'radio' => $server.':7003',
				'tunein' => 'http://tunein.com/radio/Coran-En-Espanol-mi-EDC-s190827/',
				'url' => $site.'/index.php?moshaf=4&id=4',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_spanish',
				'twitter' => 'https://twitter.com/CoranEnEspanol'
			],
			5 => [
				'title' => 'Translation of the Quran in French',
				'title_ar' => 'ترجمة القرآن الكريم بالفرنسية',
				'book' => $site.'/quran/pdf/fr_Quran_Translation_of_the_meaning.pdf',
				'rss' => $site.'/podcast/French/Abdour-Rahman_Al-Houdhaifi.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/recitation-by-sheikh-abdour/id880082885',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3F1cmFhbi51czo5OTg4LzsqLm1wMw?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/French/Abdour-Rahman_Al-Houdhaifi.txt',
				'asx' => $site.'/radio/frquraan/MediaPlayer.asx',
				'qtl' => $site.'/radio/frquraan/QuickTime.qtl',
				'ram' => $site.'/radio/frquraan/RealPlayer.ram',
				'pls' => $site.'/radio/frquraan/Winamp.pls',
				'port' => '7051',
				'server' => $server,
				'radio' => $server.':7051',
				'tunein' => 'http://tunein.com/radio/Le-Quran-Sacre-s190787/',
				'url' => $site.'/index.php?moshaf=13&id=13',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/le_caint_coran_traduit_en_francais',
				'twitter' => 'https://twitter.com/CoranEnFrancais'
			],
			6 => [
				'title' => 'Translation of the Quran in Hungarian',
				'title_ar' => 'ترجمة القرآن الكريم بالمجرية',
				'book' => $site.'/quran/pdf/hu_A_Kegyes_Korán_magyar.pdf',
				'rss' => $site.'/podcast/Hungarian/Holy_Quran_in_the_Hungarian_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558132',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjk5ODAvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Hungarian/Holy_Quran_in_the_Hungarian_Language.txt',
				'asx' => $site.'/radio/hungaria/MediaPlayer.asx',
				'qtl' => $site.'/radio/hungaria/QuickTime.qtl',
				'ram' => $site.'/radio/hungaria/RealPlayer.ram',
				'pls' => $site.'/radio/hungaria/Winamp.pls',
				'port' => '7052',
				'server' => $server,
				'radio' => $server.':7052',
				'tunein' => 'http://tunein.com/radio/Quran-in-Hungarian-s191112/',
				'url' => $site.'/index.php?moshaf=51&id=42',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_hungarian'
			],
			7 => [
				'title' => 'Translation of the Quran in Indonesian',
				'title_ar' => 'ترجمة القرآن الكريم بالإندونيسية',
				'book' => $site.'/quran/pdf/id_translation_of_the_meaning_of_the_holy_quran_in_indonesian.pdf',
				'rss' => $site.'/podcast/Indonesian/Holy_Quran_in_the_Indonesia_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558189',
				'txt' => $site.'/txt/Indonesian/Holy_Quran_in_the_Indonesia_Language.txt',
				'asx' => $site.'/radio/indquran/MediaPlayer.asx',
				'qtl' => $site.'/radio/indquran/QuickTime.qtl',
				'ram' => $site.'/radio/indquran/RealPlayer.ram',
				'pls' => $site.'/radio/indquran/Winamp.pls',
				'port' => '7053',
				'server' => $server,
				'radio' => $server.':7053',
				'tunein' => 'http://tunein.com/radio/Quran-in-Indonesian-s191111/',
				'url' => $site.'/index.php?moshaf=52&id=43',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_indonesian'
			],
			8 => [
				'title' => 'Translation of the Quran in Kashmiri',
				'title_ar' => 'ترجمة القرآن الكريم بالكشميرية',
				'book' => $site.'/quran/pdf/ks_Translation_of_the_Meaning_of_the_Holy_Quran_in_Kashmiri.pdf',
				'rss' => $site.'/podcast/Kashmiri/Translation_of_alFatihah_and_Ammah_Part_meanings.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880559905',
				'txt' => $site.'/txt/Kashmiri/Translation_of_alFatihah_and_Ammah_Part_meanings.txt',
				'asx' => $site.'/radio/kasquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/kasquraa/QuickTime.qtl',
				'ram' => $site.'/radio/kasquraa/RealPlayer.ram',
				'pls' => $site.'/radio/kasquraa/Winamp.pls',
				'port' => '7075',
				'server' => $server,
				'radio' => $server.':7075',
				'tunein' => 'http://tunein.com/radio/Quran-in-Kashmiri-s191107/',
				'url' => $site.'/index.php?moshaf=53&id=44',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_kashmiri'
			],
			9 => [
				'title' => 'Translation of the Quran in Kurdish',
				'title_ar' => 'ترجمة القرآن الكريم بالكردية',
				'rss' => $site.'/podcast/Kurdish/Saad_Al_Ghamedi_with_Kurdish_Translation.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558968',
				'txt' => $site.'/txt/Kurdish/Saad_Al_Ghamedi_with_Kurdish_Translation.txt',
				'asx' => $site.'/radio/kurquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/kurquraa/QuickTime.qtl',
				'ram' => $site.'/radio/kurquraa/RealPlayer.ram',
				'pls' => $site.'/radio/kurquraa/Winamp.pls',
				'port' => '7076',
				'server' => $server,
				'radio' => $server.':7076',
				'tunein' => 'http://tunein.com/radio/Quran-in-Kurdish-s191104/',
				'url' => $site.'/index.php?moshaf=5&id=5',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_kurdish'
			],
			10 => [
				'title' => 'Translation of the Quran in Malayalam',
				'title_ar' => 'ترجمة القرآن الكريم بالمالايالم',
				'rss' => $site.'/podcast/Hindi/Holy_Quran_in_the_Malayalam_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880085396',
				'txt' => $site.'/txt/Hindi/Holy_Quran_in_the_Malayalam_Language.txt',
				'asx' => $site.'/radio/malquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/malquraa/QuickTime.qtl',
				'ram' => $site.'/radio/malquraa/RealPlayer.ram',
				'pls' => $site.'/radio/malquraa/Winamp.pls',
				'port' => '7029',
				'server' => $server,
				'radio' => $server.':7029',
				'tunein' => 'http://tunein.com/radio/Quran-in-Malayalam-by-EDC-s191519/',
				'url' => $site.'/index.php?moshaf=10&id=10',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_malayalam',
				'twitter' => 'https://twitter.com/Quran_malayalam'
			],
			11 => [
				'title' => 'Translation of the Quran in Oromo',
				'title_ar' => 'ترجمة القرآن الكريم بالاورومية',
				'rss' => $site.'/podcast/Oromigna/Holy_Quran_in_the_Oromigna_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558539',
				'txt' => $site.'/txt/Oromigna/Holy_Quran_in_the_Oromigna_Language.txt',
				'asx' => $site.'/radio/oromigna/MediaPlayer.asx',
				'qtl' => $site.'/radio/oromigna/QuickTime.qtl',
				'ram' => $site.'/radio/oromigna/RealPlayer.ram',
				'pls' => $site.'/radio/oromigna/Winamp.pls',
				'port' => '7015',
				'server' => $server,
				'radio' => $server.':7015',
				'tunein' => 'http://tunein.com/radio/Quran-in-Oromigna-by-EDC-s223624/',
				'url' => $site.'/index.php?moshaf=45&id=40',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/quran_in_oromo'
			],
			12 => [
				'title' => 'Translation of the Quran in Tagalog',
				'title_ar' => 'ترجمة القرآن الكريم بالتاجالوغ',
				'rss' => $site.'/podcast/philippines/Tagalog.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880564959',
				'txt' => $site.'/txt/philippines/Tagalog.txt',
				'asx' => $site.'/radio/tagalog/MediaPlayer.asx',
				'qtl' => $site.'/radio/tagalog/QuickTime.qtl',
				'ram' => $site.'/radio/tagalog/RealPlayer.ram',
				'pls' => $site.'/radio/tagalog/Winamp.pls',
				'port' => '7077',
				'server' => $server,
				'radio' => $server.':7077',
				'tunein' => 'http://tunein.com/radio/Quran-in-Tagalog-by-EDC-s191063/',
				'url' => $site.'/index.php?moshaf=40&id=38',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_tagalog',
				'twitter' => 'https://twitter.com/QuranSaFilipino'
			],
			13 => [
				'title' => 'Translation of the Quran in Portuguese',
				'title_ar' => 'ترجمة القرآن الكريم بالبرتغالية',
				'book' => $site.'/quran/pdf/pt_Portuguese_translation_of_the_meanings_of_quran.pdf',
				'rss' => $site.'/podcast/Portuguese/Holy_Quran_in_the_Portuguese_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/leitura-da-traducao-sura-al/id880560062',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3F1cmFhbi51czo5OTY2LzsqLm1wMw?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Portuguese/Holy_Quran_in_the_Portuguese_Language.txt',
				'asx' => $site.'/radio/porquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/porquraa/QuickTime.qtl',
				'ram' => $site.'/radio/porquraa/RealPlayer.ram',
				'pls' => $site.'/radio/porquraa/Winamp.pls',
				'port' => '7078',
				'server' => $server,
				'radio' => $server.':7078',
				'tunein' => 'http://tunein.com/radio/O-Sagrado-Alcor%c3%a3o-em-portugu%c3%aas-pela-EDC-s190966/',
				'url' => $site.'/index.php?moshaf=12&id=12',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_portuguese',
				'twitter' => 'https://twitter.com/ONobreAlcorao'
			],
			14 => [
				'title' => 'Translation of the Quran in Albanian',
				'title_ar' => 'ترجمة القرآن الكريم بالألبانية',
				'book' => $site.'/quran/pdf/sq_translation_of_meaning_of_holy_quran_in_albanian.pdf',
				'rss' => $site.'/podcast/Albanian/Albania.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id878066202',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3F1cmFhbi51czo5OTk2LzsqLm1wMw?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Albanian/Holy_Quran_in_the_Albanian_Language.txt',
				'asx' => $site.'/radio/albanian/MediaPlayer.asx',
				'qtl' => $site.'/radio/albanian/QuickTime.qtl',
				'ram' => $site.'/radio/albanian/RealPlayer.ram',
				'pls' => $site.'/radio/albanian/Winamp.pls',
				'port' => '7079',
				'server' => $server,
				'radio' => $server.':7079',
				'tunein' => 'http://tunein.com/radio/Quran-in-Albanian-s191058/',
				'url' => $site.'/index.php?moshaf=47&id=41',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_swedish'
			],
			15 => [
				'title' => 'Translation of the Quran in Sinhalese',
				'title_ar' => 'ترجمة القرآن الكريم بالسنهالية',
				'rss' => $site.'/podcast/Sinhalese/Holy_Quran_in_the_Sinhalese_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880561079',
				'txt' => $site.'/txt/Sinhalese/Holy_Quran_in_the_Sinhalese_Language.txt',
				'asx' => $site.'/radio/sinquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/sinquraa/QuickTime.qtl',
				'ram' => $site.'/radio/sinquraa/RealPlayer.ram',
				'pls' => $site.'/radio/sinquraa/Winamp.pls',
				'port' => '7080',
				'server' => $server,
				'radio' => $server.':7080',
				'tunein' => 'http://tunein.com/radio/Quran-in-sinhala-by-EDC-s191036/',
				'url' => $site.'/index.php?moshaf=44&id=39',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_sinhalese',
				'twitter' => 'https://twitter.com/QuranInSinhala'
			],
			16 => [
				'title' => 'Translation of the Quran in Tamazight',
				'title_ar' => 'ترجمة القرآن الكريم بالأمازيقية',
				'rss' => $site.'/podcast/Tamazight/Holy_Quran_in_the_Tamazight_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558775',
				'txt' => $site.'/txt/Tamazight/Holy_Quran_in_the_Tamazight_Language.txt',
				'asx' => $site.'/radio/tamaqura/MediaPlayer.asx',
				'qtl' => $site.'/radio/tamaqura/QuickTime.qtl',
				'ram' => $site.'/radio/tamaqura/RealPlayer.ram',
				'pls' => $site.'/radio/tamaqura/Winamp.pls',
				'port' => '7014',
				'server' => $server,
				'radio' => $server.':7014',
				'tunein' => 'http://tunein.com/radio/Quran-in-Tamazight-s191101/',
				'url' => $site.'/index.php?moshaf=22&id=22',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_tamazight'
			],
			17 => [
				'title' => 'Translation of the Quran in Uyghur',
				'title_ar' => 'ترجمة القرآن الكريم بالغجرية',
				'book' => $site.'/quran/pdf/ug_kuran_kerimning_terjimisi.pdf',
				'rss' => $site.'/podcast/Uyghur/Holy_Quran_in_the_Uyghur_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880563410',
				'txt' => $site.'/txt/Uyghur/Holy_Quran_in_the_Uyghur_Language.txt',
				'asx' => $site.'/radio/uygquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/uygquraa/QuickTime.qtl',
				'ram' => $site.'/radio/uygquraa/RealPlayer.ram',
				'pls' => $site.'/radio/uygquraa/Winamp.pls',
				'port' => '7052',
				'server' => $server,
				'radio' => $server.':7052',
				'tunein' => 'http://tunein.com/radio/Quran-in-Uyghur-s191099/',
				'url' => $site.'/index.php?moshaf=6&id=6',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_uyghur'
			],
			18 => [
				'title' => 'Translation of the Quran in Vietnamese',
				'title_ar' => 'ترجمة القرآن الكريم بالفيتنامية',
				'rss' => $site.'/podcast/Vietnamese/Holy_Quran_in_the_Vietnamese_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880563437',
				'txt' => $site.'/txt/Vietnamese/Holy_Quran_in_the_Vietnamese_Language.txt',
				'asx' => $site.'/radio/viquraan/MediaPlayer.asx',
				'qtl' => $site.'/radio/viquraan/QuickTime.qtl',
				'ram' => $site.'/radio/viquraan/RealPlayer.ram',
				'pls' => $site.'/radio/viquraan/Winamp.pls',
				'port' => '7081',
				'server' => $server,
				'radio' => $server.':7081',
				'tunein' => 'http://tunein.com/radio/Quran-in-Vietnamese-s191098/',
				'url' => $site.'/index.php?moshaf=21&id=21',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_vietnamese'
			],
			19 => [
				'title' => 'Translation of the Quran in Greek',
				'title_ar' => 'ترجمة القرآن الكريم باليونانية',
				'book' => $site.'/quran/pdf/el_To_epo_Kopanio.pdf',
				'rss' => $site.'/podcast/Greek/Holy_Quran_in_the_Greek_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880085003',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjk5ODQvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Greek/Holy_Quran_in_the_Greek_Language.txt',
				'asx' => $site.'/radio/grequraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/grequraa/QuickTime.qtl',
				'ram' => $site.'/radio/grequraa/RealPlayer.ram',
				'pls' => $site.'/radio/grequraa/Winamp.pls',
				'port' => '7083',
				'server' => $server,
				'radio' => $server.':7083',
				'tunein' => 'http://tunein.com/radio/Quran-in-Greek-s191110/',
				'url' => $site.'/index.php?moshaf=20&id=20',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_greek'
			],
			20 => [
				'title' => 'Translation of the Quran in Russian',
				'title_ar' => 'ترجمة القرآن الكريم بالروسية',
				'book' => $site.'/quran/pdf/ru_quran_russian.pdf',
				'rss' => $site.'/podcast/Russian/Holy_Quran_in_the_Russian_Language_1.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558588',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjk5NjQvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Russian/Holy_Quran_in_the_Russian_Language_1.txt',
				'asx' => $site.'/radio/ruquraan/MediaPlayer.asx',
				'qtl' => $site.'/radio/ruquraan/QuickTime.qtl',
				'ram' => $site.'/radio/ruquraan/RealPlayer.ram',
				'pls' => $site.'/radio/ruquraan/Winamp.pls',
				'port' => '7082',
				'server' => $server,
				'radio' => $server.':7082',
				'tunein' => 'http://tunein.com/radio/EDC-s190958/',
				'url' => $site.'/index.php?moshaf=16&id=16',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_russian',
				'twitter' => 'https://twitter.com/KoranPoRuski'
			],
			21 => [
				'title' => 'Translation of the Quran in Urdu',
				'title_ar' => 'ترجمة القرآن الكريم بالأردو',
				'book' => $site.'/quran/pdf/ur_Translation_of_the_meaning_of_the_Holy_Quran_in_Urdu.pdf',
				'rss' => $site.'/podcast/Urdu/Sudais_and_Shuraym.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/recitation-by-sheikh-sudais/id880563387',
				'txt' => $site.'/txt/Urdu/Sudais_and_Shuraym.txt',
				'asx' => $site.'/radio/urdquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/urdquraa/QuickTime.qtl',
				'ram' => $site.'/radio/urdquraa/RealPlayer.ram',
				'pls' => $site.'/radio/urdquraa/Winamp.pls',
				'port' => '7001',
				'server' => $server,
				'radio' => $server.':7001',
				'tunein' => 'http://tunein.com/radio/Quran-in-Urdu-s191100/',
				'url' => $site.'/index.php?moshaf=27&id=3',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_vietnamese'
			],
			22 => [
				'title' => 'Translation of the Quran in Hindi',
				'title_ar' => 'ترجمة القرآن الكريم بالهندية',
				'rss' => $site.'/podcast/Hindi/Holy_Quran_in_the_Hindi_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880085088',
				'txt' => $site.'/txt/Hindi/Holy_Quran_in_the_Hindi_Language.txt',
				'asx' => $site.'/radio/hiquraan/MediaPlayer.asx',
				'qtl' => $site.'/radio/hiquraan/QuickTime.qtl',
				'ram' => $site.'/radio/hiquraan/RealPlayer.ram',
				'pls' => $site.'/radio/hiquraan/Winamp.pls',
				'port' => '7084',
				'server' => $server,
				'radio' => $server.':7084',
				'tunein' => 'http://tunein.com/radio/Quran-in-Hindi-By-EDC-s190828/',
				'url' => $site.'/index.php?moshaf=17&id=17',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_hindi',
				'twitter' => 'https://twitter.com/QuranInHindi',
				'facebook' => 'https://www.facebook.com/Quran-in-Hindi-496748057048940'
			],
			23 => [
				'title' => 'Translation of the Quran in Bengali',
				'title_ar' => 'ترجمة القرآن الكريم بالبنقالية',
				'rss' => $site.'/podcast/Bengali/Ali_Abdur-Rahman_Al-Huthaify.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/recitation-by-ali-abdur-rahman/id878083346',
				'txt' => $site.'/txt/Bengali/Ali_Abdur-Rahman_Al-Huthaify.txt',
				'asx' => $site.'/radio/banquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/banquraa/QuickTime.qtl',
				'ram' => $site.'/radio/banquraa/RealPlayer.ram',
				'pls' => $site.'/radio/banquraa/Winamp.pls',
				'port' => '7085',
				'server' => $server,
				'radio' => $server.':7085',
				'tunein' => 'http://tunein.com/radio/Quran-in-Bengali-by-EDC-s191520/',
				'url' => $site.'/index.php?moshaf=32&id=32',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_bengali',
				'twitter' => 'https://twitter.com/QuranInBengali'
			],
			24 => [
				'title' => 'Translation of the Quran in Tamil',
				'title_ar' => 'ترجمة القرآن الكريم بالتاميلية',
				'rss' => $site.'/podcast/Hindi/Holy_Quran_in_the_Tamil_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880085397',
				'txt' => $site.'/txt/Hindi/Holy_Quran_in_the_Tamil_Language.txt',
				'asx' => $site.'/radio/tamquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/tamquraa/QuickTime.qtl',
				'ram' => $site.'/radio/tamquraa/RealPlayer.ram',
				'pls' => $site.'/radio/tamquraa/Winamp.pls',
				'port' => '7002',
				'server' => $server,
				'radio' => $server.':7002',
				'tunein' => 'http://tunein.com/radio/Quran-in-Tamil-by-EDC-s191051/',
				'url' => $site.'/index.php?moshaf=14&id=14',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_in_tamil',
				'twitter' => 'https://twitter.com/tamil_Quran'
			],
			25 => [
				'title' => 'Translation of the Quran in Telugu',
				'title_ar' => 'ترجمة القرآن الكريم بالتلغو',
				'book' => $site.'/quran/pdf/te_Mushaf_new.pdf',
				'rss' => $site.'/podcast/Hindi/Holy_Quran_in_the_Telugu_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880080653',
				'txt' => $site.'/txt/Hindi/Holy_Quran_in_the_Telugu_Language.txt',
				'asx' => $site.'/radio/telquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/telquraa/QuickTime.qtl',
				'ram' => $site.'/radio/telquraa/RealPlayer.ram',
				'pls' => $site.'/radio/telquraa/Winamp.pls',
				'port' => '7086',
				'server' => $server,
				'radio' => $server.':7086',
				'tunein' => 'http://tunein.com/radio/Quran-in-Telugu-by-EDC-s191044/',
				'url' => $site.'/index.php?moshaf=15&id=15',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation-of-the-quran-in-telugu',
				'twitter' => 'https://twitter.com/QuranInTelugu'
			],
			26 => [
				'title' => 'Translation of the Quran in Kannada',
				'title_ar' => 'ترجمة القرآن الكريم بالكانادا',
				'rss' => $site.'/podcast/Hindi/Holy_Quran_in_the_kannada_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880084499',
				'txt' => $site.'/txt/Hindi/Holy_Quran_in_the_kannada_Language.txt',
				'asx' => $site.'/radio/kaquraan/MediaPlayer.asx',
				'qtl' => $site.'/radio/kaquraan/QuickTime.qtl',
				'ram' => $site.'/radio/kaquraan/RealPlayer.ram',
				'pls' => $site.'/radio/kaquraan/Winamp.pls',
				'port' => '7087',
				'server' => $server,
				'radio' => $server.':7087',
				'tunein' => 'http://tunein.com/radio/Quran-in-Kannada-s191108/',
				'url' => $site.'/index.php?moshaf=19&id=19',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_kannada'
			],
			27 => [
				'title' => 'Translation of the Quran in Thai',
				'title_ar' => 'ترجمة القرآن الكريم بالتايلندية',
				'book' => $site.'/quran/pdf/th_Holy_Quran_and_the_translation_of_the_Meaning_of_the_Thai_language.pdf',
				'rss' => $site.'/podcast/Thai/Holy_Quran_in_the_Thai_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558776',
				'txt' => $site.'/txt/Thai/Holy_Quran_in_the_Thai_Language.txt',
				'asx' => $site.'/radio/thai/MediaPlayer.asx',
				'qtl' => $site.'/radio/thai/QuickTime.qtl',
				'ram' => $site.'/radio/thai/RealPlayer.ram',
				'pls' => $site.'/radio/thai/Winamp.pls',
				'port' => '7088',
				'server' => $server,
				'radio' => $server.':7088',
				'tunein' => 'http://tunein.com/radio/Quran-in-Thai-by-EDC-s223626/',
				'url' => $site.'/index.php?moshaf=18&id=18',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_thai'
			],
			28 => [
				'title' => 'Translation of the Quran in Korean',
				'title_ar' => 'ترجمة القرآن الكريم بالكورية',
				'rss' => $site.'/podcast/Korean/Holy_Quran_in_the_Korean_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558270',
				'txt' => $site.'/txt/Korean/Holy_Quran_in_the_Korean_Language.txt',
				'asx' => $site.'/radio/korquraa/MediaPlayer.asx',
				'qtl' => $site.'/radio/korquraa/QuickTime.qtl',
				'ram' => $site.'/radio/korquraa/RealPlayer.ram',
				'pls' => $site.'/radio/korquraa/Winamp.pls',
				'port' => '7089',
				'server' => $server,
				'radio' => $server.':7089',
				'tunein' => 'http://tunein.com/radio/Quran-in-Korean-s191105/',
				'url' => $site.'/index.php?moshaf=35&id=35',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_korean'
			],
			29 => [
				'title' => 'Translation of the Quran in Chinese',
				'title_ar' => 'ترجمة القرآن الكريم بالصينية',
				'book' => $site.'/quran/pdf/zh_quran_chinese.pdf',
				'rss' => $site.'/podcast/Chinese/Holy_Quran_in_the_Chinese_Language_1.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id878091030',
				'txt' => $site.'/txt/Chinese/Holy_Quran_in_the_Chinese_Language_1.txt',
				'asx' => $site.'/radio/chquraan/MediaPlayer.asx',
				'qtl' => $site.'/radio/chquraan/QuickTime.qtl',
				'ram' => $site.'/radio/chquraan/RealPlayer.ram',
				'pls' => $site.'/radio/chquraan/Winamp.pls',
				'port' => '7090',
				'server' => $server,
				'radio' => $server.':7090',
				'tunein' => 'http://tunein.com/radio/EDC-s190956/',
				'url' => $site.'/index.php?moshaf=58&id=2',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_chinese',
				'twitter' => 'https://twitter.com/QuranInChinese'
			],
			30 => [
				'title' => 'Translation of the Quran in Punjabi',
				'title_ar' => 'ترجمة القرآن الكريم بالبنجابية',
				'rss' => $site.'/podcast/Punjabi/Holy_Quran_in_the_Punjabi_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558587',
				'txt' => $site.'/txt/Punjabi/Holy_Quran_in_the_Punjabi_Language.txt',
				'asx' => $site.'/radio/punjabi/MediaPlayer.asx',
				'qtl' => $site.'/radio/punjabi/QuickTime.qtl',
				'ram' => $site.'/radio/punjabi/RealPlayer.ram',
				'pls' => $site.'/radio/punjabi/Winamp.pls',
				'port' => '7091',
				'server' => $server,
				'radio' => $server.':7091',
				'tunein' => 'http://tunein.com/radio/Quran-in-Punjabi-s198667/',
				'url' => $site.'/index.php?moshaf=59&id=45',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_punjabi'
			],
			31 => [
				'title' => 'Translation of the Quran in Somali',
				'title_ar' => 'ترجمة القرآن الكريم بالصومالية',
				'book' => $site.'/quran/pdf/so_Quraanka_Kariimka_Iyo_Tarjamada_Macnihiisa_Ee_Afka_Soomaaliga.pdf',
				'rss' => $site.'/podcast/Soomaali/Holy_Quran_in_the_Soomaali_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558705',
				'txt' => $site.'/txt/Soomaali/Holy_Quran_in_the_Soomaali_Language.txt',
				'asx' => $site.'/radio/somali/MediaPlayer.asx',
				'qtl' => $site.'/radio/somali/QuickTime.qtl',
				'ram' => $site.'/radio/somali/RealPlayer.ram',
				'pls' => $site.'/radio/somali/Winamp.pls',
				'port' => '7008',
				'server' => $server,
				'radio' => $server.':7008',
				'url' => $site.'/index.php?moshaf=63&id=47',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_somail'
			],
			32 => [
				'title' => 'Translation of the Quran in Nigerian',
				'title_ar' => 'ترجمة القرآن الكريم بالنيجيرية',
				'rss' => $site.'/podcast/Nigerian/Holy_Quran_in_the_Nigerian_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558374',
				'txt' => $site.'/txt/Nigerian/Holy_Quran_in_the_Nigerian_Language.txt',
				'asx' => $site.'/radio/nigerian/MediaPlayer.asx',
				'qtl' => $site.'/radio/nigerian/QuickTime.qtl',
				'ram' => $site.'/radio/nigerian/RealPlayer.ram',
				'pls' => $site.'/radio/nigerian/Winamp.pls',
				'port' => '7017',
				'server' => $server,
				'radio' => $server.':7017',
				'url' => $site.'/index.php?moshaf=64&id=48',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_nigerian'
			],
			33 => [
				'title' => 'Translation of the Quran in Malay',
				'title_ar' => 'ترجمة القرآن الكريم بالماليزية',
				'rss' => $site.'/podcast/Malawi/Holy_Quran_in_the_Malawi_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880558363',
				'txt' => $site.'/txt/Malawi/Holy_Quran_in_the_Malawi_Language.txt',
				'asx' => $site.'/radio/malawian/MediaPlayer.asx',
				'qtl' => $site.'/radio/malawian/QuickTime.qtl',
				'ram' => $site.'/radio/malawian/RealPlayer.ram',
				'pls' => $site.'/radio/malawian/Winamp.pls',
				'port' => '7006',
				'server' => $server,
				'radio' => $server.':7006',
				'url' => $site.'/index.php?moshaf=65&id=49',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_malay'
			],
			34 => [
				'title' => 'Translation of the Quran in Farsi',
				'title_ar' => 'ترجمة القرآن الكريم بالفارسي',
				'book' => $site.'/quran/pdf/fa_tarjome_maani_quran_gamshadzehi.pdf',
				'rss' => $site.'/podcast/Farsi/Farsi.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880069432',
				'txt' => $site.'/txt/Farsi/Farsi.txt',
				'asx' => $site.'/radio/persian/MediaPlayer.asx',
				'qtl' => $site.'/radio/persian/QuickTime.qtl',
				'ram' => $site.'/radio/persian/RealPlayer.ram',
				'pls' => $site.'/radio/persian/Winamp.pls',
				'port' => '7093',
				'server' => $server,
				'radio' => $server.':7093',
				'tunein' => 'http://tunein.com/radio/Quran-in-Farsi-by-EDC-s223625/',
				'url' => $site.'/index.php?moshaf=66&id=50',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_farsi'
			],
			35 => [
				'title' => 'Translation of the Quran in Italiano',
				'title_ar' => 'ترجمة القرآن الكريم بالإيطالية',
				'book' => 'https://www.muslim-library.com/dl/books/it4137.pdf',
				'rss' => $site.'/podcast/Italiano/Italiano-e-arabo.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880557550',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjk5MjQvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Italiano/Italiano-e-arabo.txt',
				'asx' => $site.'/radio/italiano/MediaPlayer.asx',
				'qtl' => $site.'/radio/italiano/QuickTime.qtl',
				'ram' => $site.'/radio/italiano/RealPlayer.ram',
				'pls' => $site.'/radio/italiano/Winamp.pls',
				'port' => '7094',
				'server' => $server,
				'radio' => $server.':7094',
				'url' => $site.'/index.php?id=51',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_italian'
			],
			36 => [
				'title' => 'Tafsir in Amharic',
				'title_ar' => 'إذاعة تفسير آيات مختارة من القرآن الكريم بالأمهرية',
				'rss' => $site.'/podcast/Amharic/Amharic_tafseer_alquran.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id878077329',
				'txt' => $site.'/txt/Amharic/Amharic_tafseer_alquran.txt',
				'asx' => $site.'/radio/amharic/MediaPlayer.asx',
				'qtl' => $site.'/radio/amharic/QuickTime.qtl',
				'ram' => $site.'/radio/amharic/RealPlayer.ram',
				'pls' => $site.'/radio/amharic/Winamp.pls',
				'port' => '7095',
				'server' => $server,
				'radio' => $server.':7095',
				'url' => $site.'/index.php?id=52',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/tafsir_in_amharic'
			],
			37 => [
				'title' => 'Translation of the Quran in Yoruba',
				'title_ar' => 'ترجمة القرآن الكريم باليوربا',
				'rss' => $site.'/podcast/Yoruba/Holy_Quran_in_the_Yoruba_Language.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id880564887',
				'txt' => $site.'/txt/Yoruba/Holy_Quran_in_the_Yoruba_Language.txt',
				'asx' => $site.'/radio/yoruba/MediaPlayer.asx',
				'qtl' => $site.'/radio/yoruba/QuickTime.qtl',
				'ram' => $site.'/radio/yoruba/RealPlayer.ram',
				'pls' => $site.'/radio/yoruba/Winamp.pls',
				'port' => '7018',
				'server' => $server,
				'radio' => $server.':7018',
				'url' => $site.'/index.php?id=53',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/tanslation_of_the_quran_in_yoruba'
			],
			38 => [
				'title' => 'Tafsir by Al-Sa`di',
				'title_ar' => 'إذاعة تفسير الشيخ السعدي',
				'asx' => $site.'/radio/arabic/MediaPlayer.asx',
				'qtl' => $site.'/radio/arabic/QuickTime.qtl',
				'ram' => $site.'/radio/arabic/RealPlayer.ram',
				'pls' => $site.'/radio/arabic/Winamp.pls',
				'port' => '7004',
				'server' => $server,
				'radio' => $server.':7004'
			],
			39 => [
				'title' => 'Quran Recitation by Sheikh Abdul Basit Abdul Samad',
				'title_ar' => 'تلاوة الشيخ عبد الباسط عبد الصمد',
				'asx' => $site.'/radio/abdulbas/MediaPlayer.asx',
				'qtl' => $site.'/radio/abdulbas/QuickTime.qtl',
				'ram' => $site.'/radio/abdulbas/RealPlayer.ram',
				'pls' => $site.'/radio/abdulbas/Winamp.pls',
				'port' => '7000',
				'server' => $server,
				'radio' => $server.':7000'
			],
			40 => [
				'title' => 'Quran Recitation by Sheikh Abdul Azeez al-Ahmad',
				'title_ar' => 'تلاوة الشيخ عبد العزيز الأحمد',
				'asx' => $site.'/radio/alahmad/MediaPlayer.asx',
				'qtl' => $site.'/radio/alahmad/QuickTime.qtl',
				'ram' => $site.'/radio/alahmad/RealPlayer.ram',
				'pls' => $site.'/radio/alahmad/Winamp.pls',
				'port' => '7092',
				'server' => $server,
				'radio' => $server.':7092'
			],
			41 => [
				'title' => 'Quran Recitation by Sheikh Abdullah Ali Jabir',
				'title_ar' => 'تلاوة الشيخ عبد الله علي جابر',
				'asx' => $site.'/radio/alijabir/MediaPlayer.asx',
				'qtl' => $site.'/radio/alijabir/QuickTime.qtl',
				'ram' => $site.'/radio/alijabir/RealPlayer.ram',
				'pls' => $site.'/radio/alijabir/Winamp.pls',
				'port' => '7096',
				'server' => $server,
				'radio' => $server.':7096'
			],
			42 => [
				'title' => 'Quran Recitation by Sheikh Abdullah `Awad al-Juhani',
				'title_ar' => 'تلاوة الشيخ عبد الله عواد الجهني',
				'asx' => $site.'/radio/aljuhani/MediaPlayer.asx',
				'qtl' => $site.'/radio/aljuhani/QuickTime.qtl',
				'ram' => $site.'/radio/aljuhani/RealPlayer.ram',
				'pls' => $site.'/radio/aljuhani/Winamp.pls',
				'port' => '7032',
				'server' => $server,
				'radio' => $server.':7032'
			],
			43 => [
				'title' => 'Quran Recitation by Sheikh Abdullah Khayat',
				'title_ar' => 'تلاوة الشيخ عبد الله خياط',
				'asx' => $site.'/radio/khayat/MediaPlayer.asx',
				'qtl' => $site.'/radio/khayat/QuickTime.qtl',
				'ram' => $site.'/radio/khayat/RealPlayer.ram',
				'pls' => $site.'/radio/khayat/Winamp.pls',
				'port' => '7097',
				'server' => $server,
				'radio' => $server.':7097'
			],
			44 => [
				'title' => 'Al-Ruqyah al-Shariyyah',
				'title_ar' => 'إذاعة الرقية الشرعية من القرآن الكريم',
				'asx' => $site.'/radio/9798/MediaPlayer.asx',
				'qtl' => $site.'/radio/9798/QuickTime.qtl',
				'ram' => $site.'/radio/9798/RealPlayer.ram',
				'pls' => $site.'/radio/9798/Winamp.pls',
				'port' => '7012',
				'server' => $server,
				'radio' => $server.':7012'
			],
			45 => [
				'title' => 'Quran Recitation by Sheikh Faris `Abbad',
				'title_ar' => 'تلاوة الشيخ فارس عباد',
				'asx' => $site.'/radio/fares/MediaPlayer.asx',
				'qtl' => $site.'/radio/fares/QuickTime.qtl',
				'ram' => $site.'/radio/fares/RealPlayer.ram',
				'pls' => $site.'/radio/fares/Winamp.pls',
				'port' => '7033',
				'server' => $server,
				'radio' => $server.':7033'
			],
			46 => [
				'title' => 'Quran Recitation by Sheikh Hani Ar-Rifai',
				'title_ar' => 'تلاوة الشيخ هاني الرفاعي',
				'asx' => $site.'/radio/hani/MediaPlayer.asx',
				'qtl' => $site.'/radio/hani/QuickTime.qtl',
				'ram' => $site.'/radio/hani/RealPlayer.ram',
				'pls' => $site.'/radio/hani/Winamp.pls',
				'port' => '7098',
				'server' => $server,
				'radio' => $server.':7098'
			],
			47 => [
				'title' => 'Quran Recitation by Sheikh Khalid al-Qahtani',
				'title_ar' => 'تلاوة الشيخ خالد القحطاني',
				'asx' => $site.'/radio/qahtani/MediaPlayer.asx',
				'qtl' => $site.'/radio/qahtani/QuickTime.qtl',
				'ram' => $site.'/radio/qahtani/RealPlayer.ram',
				'pls' => $site.'/radio/qahtani/Winamp.pls',
				'port' => '7034',
				'server' => $server,
				'radio' => $server.':7034'
			],
			48 => [
				'title' => 'Quran Recitation by Sheikh Muhammad al-Luhaidan',
				'title_ar' => 'تلاوة الشيخ محمد اللحيدان',
				'asx' => $site.'/radio/luhaidan/MediaPlayer.asx',
				'qtl' => $site.'/radio/luhaidan/QuickTime.qtl',
				'ram' => $site.'/radio/luhaidan/RealPlayer.ram',
				'pls' => $site.'/radio/luhaidan/Winamp.pls',
				'port' => '7099',
				'server' => $server,
				'radio' => $server.':7099'
			],
			49 => [
				'title' => 'Quran Recitation by Sheikh Mohammad Ayoub',
				'title_ar' => 'تلاوة الشيخ محمد أيوب',
				'asx' => $site.'/radio/ayyub/MediaPlayer.asx',
				'qtl' => $site.'/radio/ayyub/QuickTime.qtl',
				'ram' => $site.'/radio/ayyub/RealPlayer.ram',
				'pls' => $site.'/radio/ayyub/Winamp.pls',
				'port' => '7100',
				'server' => $server,
				'radio' => $server.':7100'
			],
			50 => [
				'title' => 'Quran Recitation by Sheikh Muhammad Jibreel',
				'title_ar' => 'تلاوة الشيخ محمد جبريل',
				'asx' => $site.'/radio/jibreel/MediaPlayer.asx',
				'qtl' => $site.'/radio/jibreel/QuickTime.qtl',
				'ram' => $site.'/radio/jibreel/RealPlayer.ram',
				'pls' => $site.'/radio/jibreel/Winamp.pls',
				'port' => '7101',
				'server' => $server,
				'radio' => $server.':7101'
			],
			51 => [
				'title' => 'Quran Recitation by Sheikh Abu Bakr al-Shatiri',
				'title_ar' => 'تلاوة الشيخ أبو بكر الشاطري',
				'asx' => $site.'/radio/shatri/MediaPlayer.asx',
				'qtl' => $site.'/radio/shatri/QuickTime.qtl',
				'ram' => $site.'/radio/shatri/RealPlayer.ram',
				'pls' => $site.'/radio/shatri/Winamp.pls',
				'port' => '7102',
				'server' => $server,
				'radio' => $server.':7102'
			],
			52 => [
				'title' => 'Reading of Warsh from Nafi`by Alkouchi`',
				'title_ar' => 'رواية ورش عن نافع',
				'asx' => $site.'/radio/alkouchi/MediaPlayer.asx',
				'qtl' => $site.'/radio/alkouchi/QuickTime.qtl',
				'ram' => $site.'/radio/alkouchi/RealPlayer.ram',
				'pls' => $site.'/radio/alkouchi/Winamp.pls',
				'port' => '7103',
				'server' => $server,
				'radio' => $server.':7103'
			],
			53 => [
				'title' => 'Quran Recitation by Sheikh Nasser Al-Qatami',
				'title_ar' => 'تلاوة الشيخ ناصر القطامي',
				'asx' => $site.'/radio/qatam/MediaPlayer.asx',
				'qtl' => $site.'/radio/qatam/QuickTime.qtl',
				'ram' => $site.'/radio/qatam/RealPlayer.ram',
				'pls' => $site.'/radio/qatam/Winamp.pls',
				'port' => '7104',
				'server' => $server,
				'radio' => $server.':7104'
			],
			54 => [
				'title' => 'Quran Recitation by Sheikh Yasser Al-Dosari',
				'title_ar' => 'تلاوة الشيخ ياسر الدوسري',
				'asx' => $site.'/radio/aldosari/MediaPlayer.asx',
				'qtl' => $site.'/radio/aldosari/QuickTime.qtl',
				'ram' => $site.'/radio/aldosari/RealPlayer.ram',
				'pls' => $site.'/radio/aldosari/Winamp.pls',
				'port' => '7105',
				'server' => $server,
				'radio' => $server.':7105'
			],
			55 => [
				'title' => 'Reading of Al-Bizzi from Ibn Kathir Recitation by Yosuf Nooh',
				'title_ar' => 'رواية البزي عن ابن كثير',
				'asx' => $site.'/radio/bazzi/MediaPlayer.asx',
				'qtl' => $site.'/radio/bazzi/QuickTime.qtl',
				'ram' => $site.'/radio/bazzi/RealPlayer.ram',
				'pls' => $site.'/radio/bazzi/Winamp.pls',
				'port' => '7031',
				'server' => $server,
				'radio' => $server.':7031'
			],
			56 => [
				'title' => 'Reading of Al-Duri from Abu `Amr Recitation by Al-Husary',
				'title_ar' => 'رواية الدوري عن أبي عمرو',
				'asx' => $site.'/radio/dori/MediaPlayer.asx',
				'qtl' => $site.'/radio/dori/QuickTime.qtl',
				'ram' => $site.'/radio/dori/RealPlayer.ram',
				'pls' => $site.'/radio/dori/Winamp.pls',
				'port' => '7024',
				'server' => $server,
				'radio' => $server.':7024'
			],
			57 => [
				'title' => 'Reading of Ruh from Ya`qub al-Hadrami Recitation by Al-Saltani',
				'title_ar' => 'رواية روح عن يعقوب الحضرمي',
				'asx' => $site.'/radio/rooh/MediaPlayer.asx',
				'qtl' => $site.'/radio/rooh/QuickTime.qtl',
				'ram' => $site.'/radio/rooh/RealPlayer.ram',
				'pls' => $site.'/radio/rooh/Winamp.pls',
				'port' => '7106',
				'server' => $server,
				'radio' => $server.':7106'
			],
			58 => [
				'title' => 'Shubah from Asim ibn Abi Al-Nuju by Abdul-Rashid Sufi',
				'title_ar' => 'رواية شعبة عن عاصم',
				'asx' => $site.'/radio/sofi/MediaPlayer.asx',
				'qtl' => $site.'/radio/sofi/QuickTime.qtl',
				'ram' => $site.'/radio/sofi/RealPlayer.ram',
				'pls' => $site.'/radio/sofi/Winamp.pls',
				'port' => '7107',
				'server' => $server,
				'radio' => $server.':7107'
			],
			59 => [
				'title' => 'Ibn Dhakwan from Ibn `Amir Recitation by Al-Biltagi',
				'title_ar' => 'رواية ابن ذكوان عن ابن عامر',
				'asx' => $site.'/radio/zakwan/MediaPlayer.asx',
				'qtl' => $site.'/radio/zakwan/QuickTime.qtl',
				'ram' => $site.'/radio/zakwan/RealPlayer.ram',
				'pls' => $site.'/radio/zakwan/Winamp.pls',
				'port' => '7108',
				'server' => $server,
				'radio' => $server.':7108'
			],
			60 => [
				'title' => 'Quran Recitation by Sheikh Mishary Al-Ifasy',
				'title_ar' => 'تلاوة الشيخ مشاري العفاسي',
				'asx' => $site.'/radio/alafasy/MediaPlayer.asx',
				'qtl' => $site.'/radio/alafasy/QuickTime.qtl',
				'ram' => $site.'/radio/alafasy/RealPlayer.ram',
				'pls' => $site.'/radio/alafasy/Winamp.pls',
				'port' => '10998',
				'server' => $server.':',
				'radio' => $server.':10998'
			],
			61 => [
				'title' => 'Quran Recitation by Sheikh Mahmoud Khalil Al-Husary',
				'title_ar' => 'تلاوة الشيخ محمود خليل الحصري',
				'asx' => $site.'/radio/alhusary/MediaPlayer.asx',
				'qtl' => $site.'/radio/alhusary/QuickTime.qtl',
				'ram' => $site.'/radio/alhusary/RealPlayer.ram',
				'pls' => $site.'/radio/alhusary/Winamp.pls',
				'port' => '7007',
				'server' => $server,
				'radio' => $server.':7007'
			],
			62 => [
				'title' => 'Quran Recitation by Sheikh Muhammad Siddiq al-Minshawi',
				'title_ar' => 'تلاوة الشيخ محمد صديق المنشاوي',
				'asx' => $site.'/radio/minshaaw/MediaPlayer.asx',
				'qtl' => $site.'/radio/minshaaw/QuickTime.qtl',
				'ram' => $site.'/radio/minshaaw/RealPlayer.ram',
				'pls' => $site.'/radio/minshaaw/Winamp.pls',
				'port' => '7036',
				'server' => $server,
				'radio' => $server.':7036'
			],
			63 => [
				'title' => 'Fatwas by Ibn `Uthaymin',
				'title_ar' => 'إذاعة فتاوى الشيخ ابن عثيمين',
				'asx' => $site.'/radio/othaimen/MediaPlayer.asx',
				'qtl' => $site.'/radio/othaimen/QuickTime.qtl',
				'ram' => $site.'/radio/othaimen/RealPlayer.ram',
				'pls' => $site.'/radio/othaimen/Winamp.pls',
				'port' => '7147',
				'server' => $server,
				'radio' => $server.':7147'
			],
			64 => [
				'title' => 'Tafsir by Al-Sha`rawi (Arabic)',
				'title_ar' => 'إذاعة تفسير الإمام الشعراوي',
				'asx' => $site.'/radio/sharawy/MediaPlayer.asx',
				'qtl' => $site.'/radio/sharawy/QuickTime.qtl',
				'ram' => $site.'/radio/sharawy/RealPlayer.ram',
				'pls' => $site.'/radio/sharawy/Winamp.pls',
				'port' => '7148',
				'server' => $server,
				'radio' => $server.':7148'
			],
			65 => [
				'title' => 'Quran Recitation by Sheikh Mohammad Al-Tablawi',
				'title_ar' => 'تلاوة الشيخ محمد الطبلاوي',
				'asx' => $site.'/radio/ltablawi/MediaPlayer.asx',
				'qtl' => $site.'/radio/ltablawi/QuickTime.qtl',
				'ram' => $site.'/radio/ltablawi/RealPlayer.ram',
				'pls' => $site.'/radio/ltablawi/Winamp.pls',
				'port' => '7038',
				'server' => $server,
				'radio' => $server.':7038'
			],
			66 => [
				'title' => 'Tafsir in Swahili',
				'title_ar' => 'إذاعة تفسير القرآن بالسواحيلية',
				'book' => $site.'/quran/pdf/Translation_of_the_Quran_in_Swahili.pdf',
				'rss' => $site.'/podcast/Swahili/Translation_of_the_Quran_in_Swahili.rss',
				'txt' => $site.'/txt/Swahili/Translation_of_the_Quran_in_Swahili.txt',
				'asx' => $site.'/radio/swahili/MediaPlayer.asx',
				'qtl' => $site.'/radio/swahili/QuickTime.qtl',
				'ram' => $site.'/radio/swahili/RealPlayer.ram',
				'pls' => $site.'/radio/swahili/Winamp.pls',
				'port' => '7109',
				'server' => $server,
				'radio' => $server.':7109',
				'url' => $site.'/index.php?moshaf=72&id=55',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/tafsir_in_swahili'
			],
			67 => [
				'title' => 'Translation of the Quran in Pashto',
				'title_ar' => 'ترجمة القرآن الكريم بالبشتو',
				'rss' => $site.'/podcast/Pashto/Holy_Quran_in_the_Pashto_Language.rss',
				'txt' => $site.'/txt/Pashto/Holy_Quran_in_the_Pashto_Language.txt',
				'asx' => $site.'/radio/pashtoqu/MediaPlayer.asx',
				'qtl' => $site.'/radio/pashtoqu/QuickTime.qtl',
				'ram' => $site.'/radio/pashtoqu/RealPlayer.ram',
				'pls' => $site.'/radio/pashtoqu/Winamp.pls',
				'port' => '7110',
				'server' => $server,
				'radio' => $server.':7110',
				'tunein' => '',
				'url' => $site.'/index.php?moshaf=72&id=54',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_pashto'
			],
			68 => [
				'title' => 'Tafsir by Al-Sa`di in Russian',
				'title_ar' => 'إذاعة تفسير الشيخ السعدي بالروسية',
				'txt' => $site.'/txt/Russian/Holy_Quran_in_the_Russian_Language_1.txt',
				'asx' => $site.'/radio/saadirussian/MediaPlayer.asx',
				'qtl' => $site.'/radio/saadirussian/QuickTime.qtl',
				'ram' => $site.'/radio/saadirussian/RealPlayer.ram',
				'pls' => $site.'/radio/saadirussian/Winamp.pls',
				'port' => '7111',
				'server' => $server,
				'radio' => $server.':7111',
				'tunein' => 'http://tunein.com/radio/EDC-s190958/',
				'url' => $site.'/index.php?moshaf=16&id=16'
			],
			69 => [
				'title' => 'Quran Recitation by Sheikh Abdullah Basfar',
				'title_ar' => 'تلاوة الشيخ عبد الله بصفر',
				'asx' => $site.'/radio/9846/MediaPlayer.asx',
				'qtl' => $site.'/radio/9846/QuickTime.qtl',
				'ram' => $site.'/radio/9846/RealPlayer.ram',
				'pls' => $site.'/radio/9846/Winamp.pls',
				'port' => '7112',
				'server' => $server,
				'radio' => $server.':7112'
			],
			70 => [
				'title' => 'Quran Recitation by Sheikh Ahmad al-`Ajmi',
				'title_ar' => 'تلاوة الشيخ أحمد العجمي',
				'asx' => $site.'/radio/9852/MediaPlayer.asx',
				'qtl' => $site.'/radio/9852/QuickTime.qtl',
				'ram' => $site.'/radio/9852/RealPlayer.ram',
				'pls' => $site.'/radio/9852/Winamp.pls',
				'port' => '7113',
				'server' => $server,
				'radio' => $server.':7113'
			],
			71 => [
				'title' => 'Quran Recitation by Sheikh Ali Al-Hudhaifi',
				'title_ar' => 'تلاوة الشيخ علي الحذيفي',
				'asx' => $site.'/radio/9844/MediaPlayer.asx',
				'qtl' => $site.'/radio/9844/QuickTime.qtl',
				'ram' => $site.'/radio/9844/RealPlayer.ram',
				'pls' => $site.'/radio/9844/Winamp.pls',
				'port' => '7114',
				'server' => $server,
				'radio' => $server.':7114'
			],
			72 => [
				'title' => 'Quran Recitation by Sheikh Abdul Mohsin Al-Qasim',
				'title_ar' => 'تلاوة الشيخ عبد المحسن القاسم',
				'asx' => $site.'/radio/9842/MediaPlayer.asx',
				'qtl' => $site.'/radio/9842/QuickTime.qtl',
				'ram' => $site.'/radio/9842/RealPlayer.ram',
				'pls' => $site.'/radio/9842/Winamp.pls',
				'port' => '7115',
				'server' => $server,
				'radio' => $server.':7115'
			],
			73 => [
				'title' => 'Quran Recitation by Sheikh Khalifah Al-Tunaiji',
				'title_ar' => 'تلاوة الشيخ خليفة الطنيجي',
				'asx' => $site.'/radio/altunaiji/MediaPlayer.asx',
				'qtl' => $site.'/radio/altunaiji/QuickTime.qtl',
				'ram' => $site.'/radio/altunaiji/RealPlayer.ram',
				'pls' => $site.'/radio/altunaiji/Winamp.pls',
				'port' => '7116',
				'server' => $server,
				'radio' => $server.':7116'
			],
			74 => [
				'title' => 'Quran Recitation by Sheikh Ibrahim Al-Akhdar',
				'title_ar' => 'تلاوة الشيخ إبراهيم الأخضر',
				'asx' => $site.'/radio/alakhdar/MediaPlayer.asx',
				'qtl' => $site.'/radio/alakhdar/QuickTime.qtl',
				'ram' => $site.'/radio/alakhdar/RealPlayer.ram',
				'pls' => $site.'/radio/alakhdar/Winamp.pls',
				'port' => '7117',
				'server' => $server,
				'radio' => $server.':7117'
			],
			75 => [
				'title' => 'Quran Recitation by Sheikh Saud Al-Shuraim',
				'title_ar' => 'تلاوة الشيخ سعود الشريم',
				'asx' => $site.'/radio/alshuraim/MediaPlayer.asx',
				'qtl' => $site.'/radio/alshuraim/QuickTime.qtl',
				'ram' => $site.'/radio/alshuraim/RealPlayer.ram',
				'pls' => $site.'/radio/alshuraim/Winamp.pls',
				'port' => '7118',
				'server' => $server,
				'radio' => $server.':7118'
			],
			76 => [
				'title' => 'Quran Recitation by Abdul Rahman Al-Sudais',
				'title_ar' => 'تلاوة الشيخ عبد الرحمن السديس',
				'asx' => $site.'/radio/alsudais/MediaPlayer.asx',
				'qtl' => $site.'/radio/alsudais/QuickTime.qtl',
				'ram' => $site.'/radio/alsudais/RealPlayer.ram',
				'pls' => $site.'/radio/alsudais/Winamp.pls',
				'port' => '7119',
				'server' => $server,
				'radio' => $server.':7119'
			],
			77 => [
				'title' => 'Quran Recitation by Sheikh Sa`d Al-Ghamidi',
				'title_ar' => 'تلاوة الشيخ سعد الغامدي',
				'asx' => $site.'/radio/alghamidi/MediaPlayer.asx',
				'qtl' => $site.'/radio/alghamidi/QuickTime.qtl',
				'ram' => $site.'/radio/alghamidi/RealPlayer.ram',
				'pls' => $site.'/radio/alghamidi/Winamp.pls',
				'port' => '7011',
				'server' => $server,
				'radio' => $server.':7011'
			],
			78 => [
				'title' => 'Quran Recitation by Sheikh Maher Al Muaiqly',
				'title_ar' => 'تلاوة الشيخ ماهر المعيقلي',
				'asx' => $site.'/radio/muaiqlyen/MediaPlayer.asx',
				'qtl' => $site.'/radio/muaiqlyen/QuickTime.qtl',
				'ram' => $site.'/radio/muaiqlyen/RealPlayer.ram',
				'pls' => $site.'/radio/muaiqlyen/Winamp.pls',
				'port' => '7005',
				'server' => $server,
				'radio' => $server.':7005'
			],
			79 => [
				'title' => 'Reading of Ibn Jummaz from Abu Jafar by Muftah Al-Sultani',
				'title_ar' => 'مفتاح السلطني برواية ابن جماز عن أبي جعفر',
				'asx' => $site.'/radio/alsultani/MediaPlayer.asx',
				'qtl' => $site.'/radio/alsultani/QuickTime.qtl',
				'ram' => $site.'/radio/alsultani/RealPlayer.ram',
				'pls' => $site.'/radio/alsultani/Winamp.pls',
				'port' => '7019',
				'server' => $server,
				'radio' => $server.':7019'
			],
			80 => [
				'title' => 'Reading of Abu Al-Harith from Al-Kisai by Abdul-Rashid Sufi',
				'title_ar' => 'رواية أبو الحارث عن الكسائي',
				'asx' => $site.'/radio/9836/MediaPlayer.asx',
				'qtl' => $site.'/radio/9836/QuickTime.qtl',
				'ram' => $site.'/radio/9836/RealPlayer.ram',
				'pls' => $site.'/radio/9836/Winamp.pls',
				'port' => '7020',
				'server' => $server,
				'radio' => $server.':7020'
			],
			81 => [
				'title' => 'Tafsir in Fulani',
				'title_ar' => 'إذاعة تفسير القرآن بالفولانية',
				'asx' => $site.'/radio/falata/MediaPlayer.asx',
				'qtl' => $site.'/radio/falata/QuickTime.qtl',
				'ram' => $site.'/radio/falata/RealPlayer.ram',
				'pls' => $site.'/radio/falata/Winamp.pls',
				'port' => '7149',
				'server' => $server,
				'radio' => $server.':7149'
			],
			82 => [
				'title' => 'Reading of Al-Duri from Abu Amr by Al-Fatih Muhammad Zubayr',
				'title_ar' => 'إذاعة القارئ الفاتح محمد الزبير برواية الدوري',
				'asx' => $site.'/radio/9832/MediaPlayer.asx',
				'qtl' => $site.'/radio/9832/QuickTime.qtl',
				'ram' => $site.'/radio/9832/RealPlayer.ram',
				'pls' => $site.'/radio/9832/Winamp.pls',
				'port' => '7022',
				'server' => $server,
				'radio' => $server.':7022'
			],
			83 => [
				'title' => 'Reading of Al-Duri from Abu Amr by Abul-Rashid Al-Sufi',
				'title_ar' => 'إذاعة القارئ عبد الرشيد صوفي برواية الدوري',
				'asx' => $site.'/radio/9830/MediaPlayer.asx',
				'qtl' => $site.'/radio/9830/QuickTime.qtl',
				'ram' => $site.'/radio/9830/RealPlayer.ram',
				'pls' => $site.'/radio/9830/Winamp.pls',
				'port' => '7023',
				'server' => $server,
				'radio' => $server.':7023'
			],
			84 => [
				'title' => 'Reading of Al-Duri from Abu Amr by Muftah Al-Saltani',
				'title_ar' => 'إذاعة القارئ مفتاح السلطني برواية الدوري',
				'asx' => $site.'/radio/9828/MediaPlayer.asx',
				'qtl' => $site.'/radio/9828/QuickTime.qtl',
				'ram' => $site.'/radio/9828/RealPlayer.ram',
				'pls' => $site.'/radio/9828/Winamp.pls',
				'port' => '7021',
				'server' => $server,
				'radio' => $server.':7021'
			],
			85 => [
				'title' => 'Reading of Al-Susi from Abu Amr by Abdul-Rashid Al-Sufi',
				'title_ar' => 'إذاعة القارئ عبد الرشيد صوفي برواية السوسي',
				'asx' => $site.'/radio/9826/MediaPlayer.asx',
				'qtl' => $site.'/radio/9826/QuickTime.qtl',
				'ram' => $site.'/radio/9826/RealPlayer.ram',
				'pls' => $site.'/radio/9826/Winamp.pls',
				'port' => '7025',
				'server' => $server,
				'radio' => $server.':7025'
			],
			86 => [
				'title' => 'Reading of Khalaf from Hamzah by Abdul-Rashid Al-Sufi',
				'title_ar' => 'إذاعة القارئ عبد الرشيد صوفي برواية خلف',
				'asx' => $site.'/radio/9824/MediaPlayer.asx',
				'qtl' => $site.'/radio/9824/QuickTime.qtl',
				'ram' => $site.'/radio/9824/RealPlayer.ram',
				'pls' => $site.'/radio/9824/Winamp.pls',
				'port' => '7026',
				'server' => $server,
				'radio' => $server.':7026'
			],
			87 => [
				'title' => 'Reading of Ruways from Yaqub Al-Hadrami by Yasir Al-Mazrui',
				'title_ar' => 'إذاعة القارئ ياسر المزروعي برواية رويس',
				'asx' => $site.'/radio/9822/MediaPlayer.asx',
				'qtl' => $site.'/radio/9822/QuickTime.qtl',
				'ram' => $site.'/radio/9822/RealPlayer.ram',
				'pls' => $site.'/radio/9822/Winamp.pls',
				'port' => '7028',
				'server' => $server,
				'radio' => $server.':7028'
			],
			88 => [
				'title' => 'Reading of Qalun from Nafi by Ahmad Khidr Al-Tarabulsi',
				'title_ar' => 'إذاعة القارئ أحمد خضر الطرابلسي برواية قالون',
				'asx' => $site.'/radio/9820/MediaPlayer.asx',
				'qtl' => $site.'/radio/9820/QuickTime.qtl',
				'ram' => $site.'/radio/9820/RealPlayer.ram',
				'pls' => $site.'/radio/9820/Winamp.pls',
				'port' => '7120',
				'server' => $server,
				'radio' => $server.':7120'
			],
			89 => [
				'title' => 'Reading of Qalun from Nafi by Al-Dukali Muhammad Al-Alim',
				'title_ar' => 'إذاعة القارئ الدوكالي محمد العالم برواية قالون',
				'asx' => $site.'/radio/9818/MediaPlayer.asx',
				'qtl' => $site.'/radio/9818/QuickTime.qtl',
				'ram' => $site.'/radio/9818/RealPlayer.ram',
				'pls' => $site.'/radio/9818/Winamp.pls',
				'port' => '7121',
				'server' => $server,
				'radio' => $server.':7121'
			],
			90 => [
				'title' => 'Reading of Qalun from Nafi by Ali Al-Hudhaifi',
				'title_ar' => 'إذاعة القارئ علي الحذيفي برواية قالون',
				'asx' => $site.'/radio/9816/MediaPlayer.asx',
				'qtl' => $site.'/radio/9816/QuickTime.qtl',
				'ram' => $site.'/radio/9816/RealPlayer.ram',
				'pls' => $site.'/radio/9816/Winamp.pls',
				'port' => '7122',
				'server' => $server,
				'radio' => $server.':7122'
			],
			91 => [
				'title' => 'Reading of Qalun from Nafi by Mahmoud Khalil Al-Husari',
				'title_ar' => 'إذاعة الشيخ محمود خليل الحصري برواية قالون',
				'asx' => $site.'/radio/9814/MediaPlayer.asx',
				'qtl' => $site.'/radio/9814/QuickTime.qtl',
				'ram' => $site.'/radio/9814/RealPlayer.ram',
				'pls' => $site.'/radio/9814/Winamp.pls',
				'port' => '7123',
				'server' => $server,
				'radio' => $server.':7123'
			],
			92 => [
				'title' => 'Reading of Warsh from Nafi by Ibrahim Al-Dusari',
				'title_ar' => 'إذاعة القارئ إبراهيم الدوسري برواية ورش',
				'asx' => $site.'/radio/9812/MediaPlayer.asx',
				'qtl' => $site.'/radio/9812/QuickTime.qtl',
				'ram' => $site.'/radio/9812/RealPlayer.ram',
				'pls' => $site.'/radio/9812/Winamp.pls',
				'port' => '7124',
				'server' => $server,
				'radio' => $server.':7124'
			],
			93 => [
				'title' => 'Reading of Warsh from Nafi by Abdul-Basit Abdul-Samad',
				'title_ar' => 'إذاعة الشيخ عبد الباسط عبد الصمد برواية ورش',
				'asx' => $site.'/radio/9810/MediaPlayer.asx',
				'qtl' => $site.'/radio/9810/QuickTime.qtl',
				'ram' => $site.'/radio/9810/RealPlayer.ram',
				'pls' => $site.'/radio/9810/Winamp.pls',
				'port' => '7125',
				'server' => $server,
				'radio' => $server.':7125'
			],
			94 => [
				'title' => 'Reading of Warsh from Nafi by Umar Al-Qazabri',
				'title_ar' => 'إذاعة القارئ عمر القزابري برواية ورش',
				'asx' => $site.'/radio/9808/MediaPlayer.asx',
				'qtl' => $site.'/radio/9808/QuickTime.qtl',
				'ram' => $site.'/radio/9808/RealPlayer.ram',
				'pls' => $site.'/radio/9808/Winamp.pls',
				'port' => '7126',
				'server' => $server,
				'radio' => $server.':7126'
			],
			95 => [
				'title' => 'Reading of Warsh from Nafi by Muhammad Al-Tayyib Himdan',
				'title_ar' => 'إذاعة القارئ محمد الطيب حمدان برواية ورش',
				'asx' => $site.'/radio/9806/MediaPlayer.asx',
				'qtl' => $site.'/radio/9806/QuickTime.qtl',
				'ram' => $site.'/radio/9806/RealPlayer.ram',
				'pls' => $site.'/radio/9806/Winamp.pls',
				'port' => '7127',
				'server' => $server,
				'radio' => $server.':7127'
			],
			96 => [
				'title' => 'Reading of Warsh from Nafi by Mustafa Gharbi',
				'title_ar' => 'إذاعة القارئ مصطفى غربي برواية ورش',
				'asx' => $site.'/radio/9804/MediaPlayer.asx',
				'qtl' => $site.'/radio/9804/QuickTime.qtl',
				'ram' => $site.'/radio/9804/RealPlayer.ram',
				'pls' => $site.'/radio/9804/Winamp.pls',
				'port' => '7128',
				'server' => $server,
				'radio' => $server.':7128'
			],
			97 => [
				'title' => 'Reading of Warsh from Nafi by Yasin Al-Jazairi',
				'title_ar' => 'إذاعة القارئ ياسين الجزائري برواية ورش',
				'asx' => $site.'/radio/9802/MediaPlayer.asx',
				'qtl' => $site.'/radio/9802/QuickTime.qtl',
				'ram' => $site.'/radio/9802/RealPlayer.ram',
				'pls' => $site.'/radio/9802/Winamp.pls',
				'port' => '7129',
				'server' => $server,
				'radio' => $server.':7129'
			],
			98 => [
				'title' => 'Reading of Ruways from Yaqub al-Hadrami by Mufah Muhammad Al-Saltani',
				'title_ar' => 'إذاعة القارئ مفتاح محمد السلطني برواية رويس',
				'asx' => $site.'/radio/9800/MediaPlayer.asx',
				'qtl' => $site.'/radio/9800/QuickTime.qtl',
				'ram' => $site.'/radio/9800/RealPlayer.ram',
				'pls' => $site.'/radio/9800/Winamp.pls',
				'port' => '7027',
				'server' => $server,
				'radio' => $server.':7027'
			],
			99 => [
				'title' => 'Quran Recitation by Sheikh Tawfiq Al-Saigh',
				'title_ar' => 'تلاوة الشيخ توفيق الصايغ',
				'asx' => $site.'/radio/9796/MediaPlayer.asx',
				'qtl' => $site.'/radio/9796/QuickTime.qtl',
				'ram' => $site.'/radio/9796/RealPlayer.ram',
				'pls' => $site.'/radio/9796/Winamp.pls',
				'port' => '7130',
				'server' => $server,
				'radio' => $server.':7130'
			],
			100 => [
				'title' => 'Quran Recitation by Sheikh Khalid AL-Jalil',
				'title_ar' => 'تلاوة الشيخ خالد الجليل',
				'asx' => $site.'/radio/9794/MediaPlayer.asx',
				'qtl' => $site.'/radio/9794/QuickTime.qtl',
				'ram' => $site.'/radio/9794/RealPlayer.ram',
				'pls' => $site.'/radio/9794/Winamp.pls',
				'port' => '7030',
				'server' => $server,
				'radio' => $server.':7030'
			],
			101 => [
				'title' => 'Quran Recitation by Sheikh Zaki Daghistani',
				'title_ar' => 'تلاوة الشيخ زكي داغستاني',
				'asx' => $site.'/radio/9792/MediaPlayer.asx',
				'qtl' => $site.'/radio/9792/QuickTime.qtl',
				'ram' => $site.'/radio/9792/RealPlayer.ram',
				'pls' => $site.'/radio/9792/Winamp.pls',
				'port' => '7035',
				'server' => $server,
				'radio' => $server.':7035'
			],
			102 => [
				'title' => 'Quran Recitation by Sheikh Abdulbari Al-Thubayti',
				'title_ar' => 'تلاوة الشيخ عبد الرحمن الثبيتي',
				'asx' => $site.'/radio/9790/MediaPlayer.asx',
				'qtl' => $site.'/radio/9790/QuickTime.qtl',
				'ram' => $site.'/radio/9790/RealPlayer.ram',
				'pls' => $site.'/radio/9790/Winamp.pls',
				'port' => '7131',
				'server' => $server,
				'radio' => $server.':7131'
			],
			103 => [
				'title' => 'Quran Recitation by Sheikh Mahmud Ali Al-Banna',
				'title_ar' => 'تلاوة الشيخ محمود علي البنا',
				'asx' => $site.'/radio/9788/MediaPlayer.asx',
				'qtl' => $site.'/radio/9788/QuickTime.qtl',
				'ram' => $site.'/radio/9788/RealPlayer.ram',
				'pls' => $site.'/radio/9788/Winamp.pls',
				'port' => '7010',
				'server' => $server,
				'radio' => $server.':7010'
			],
			104 => [
				'title' => 'Quran Recitation by Sheikh Mustafa Ismail',
				'title_ar' => 'تلاوة الشيخ مصطفى إسماعيل',
				'asx' => $site.'/radio/9786/MediaPlayer.asx',
				'qtl' => $site.'/radio/9786/QuickTime.qtl',
				'ram' => $site.'/radio/9786/RealPlayer.ram',
				'pls' => $site.'/radio/9786/Winamp.pls',
				'port' => '7132',
				'server' => $server,
				'radio' => $server.':7132'
			],
			105 => [
				'title' => 'Quran Recitation by Sheikh Wadi Al-Yamani',
				'title_ar' => 'تلاوة الشيخ وديع اليمني',
				'asx' => $site.'/radio/9784/MediaPlayer.asx',
				'qtl' => $site.'/radio/9784/QuickTime.qtl',
				'ram' => $site.'/radio/9784/RealPlayer.ram',
				'pls' => $site.'/radio/9784/Winamp.pls',
				'port' => '7133',
				'server' => $server,
				'radio' => $server.':7133'
			],
			106 => [
				'title' => 'Quran Recitation by Jaza Al-Suweilih',
				'title_ar' => 'تلاوة الشيخ جزاع صويلح',
				'asx' => $site.'/radio/9780/MediaPlayer.asx',
				'qtl' => $site.'/radio/9780/QuickTime.qtl',
				'ram' => $site.'/radio/9780/RealPlayer.ram',
				'pls' => $site.'/radio/9780/Winamp.pls',
				'port' => '7134',
				'server' => $server,
				'radio' => $server.':7134'
			],
			107 => [
				'title' => 'Quran Recitation by Abdul-Rahman Al-Usi',
				'title_ar' => 'تلاوة الشيخ عبد الرحمن العوسي',
				'asx' => $site.'/radio/9778/MediaPlayer.asx',
				'qtl' => $site.'/radio/9778/QuickTime.qtl',
				'ram' => $site.'/radio/9778/RealPlayer.ram',
				'pls' => $site.'/radio/9778/Winamp.pls',
				'port' => '7037',
				'server' => $server,
				'radio' => $server.':7037'
			],
			108 => [
				'title' => 'Quran Recitation by Muhammad Siddiq AL-Minshawi (Al-Mushaf Al-Mujawwad)',
				'title_ar' => 'تلاوة الشيخ محمد صديق المنشاوي - مجود',
				'asx' => $site.'/radio/9776/MediaPlayer.asx',
				'qtl' => $site.'/radio/9776/QuickTime.qtl',
				'ram' => $site.'/radio/9776/RealPlayer.ram',
				'pls' => $site.'/radio/9776/Winamp.pls',
				'port' => '7135',
				'server' => $server,
				'radio' => $server.':7135'
			],
			109 => [
				'title' => 'Translation of the Quran in Romanian',
				'title_ar' => 'ترجمة القرآن الكريم بالرومانية',
				'book' => $site.'/quran/pdf/ro_Traducerea_sensurilor_Coranului_cel_Sfant_in_limba_romana.pdf',
				'rss' => $site.'/podcast/Romanian/Romanian.rss',
				'podcast' => 'https://podcasts.apple.com/kw/podcast/translation-of-the-quran-in-romanian/id1329488517',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjk3NzQvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Romanian/Romanian.txt',
				'asx' => $site.'/radio/9774/MediaPlayer.asx',
				'qtl' => $site.'/radio/9774/QuickTime.qtl',
				'ram' => $site.'/radio/9774/RealPlayer.ram',
				'pls' => $site.'/radio/9774/Winamp.pls',
				'port' => '7009',
				'server' => $server,
				'radio' => $server.':7009',
				'url' => $site.'/translation-quran-romanian/',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_romanian'
			],
			110 => [
				'title' => 'Translation of the Quran in Swedish',
				'title_ar' => 'ترجمة القرآن الكريم بالسويدية',
				'rss' => $site.'/podcast/Swedish/Translation_of_the_Meaning_of_the_Quran_in_Swedish.rss',
				'podcast' => 'https://itunes.apple.com/kw/podcast/translation-meaning-quran/id1000619823',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3F1cmFhbi51czo5NzcyLzsqLm1wMzM?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Swedish/Translation_of_the_Meaning_of_the_Quran_in_Swedish.txt',
				'asx' => $site.'/radio/9772/MediaPlayer.asx',
				'qtl' => $site.'/radio/9772/QuickTime.qtl',
				'ram' => $site.'/radio/9772/RealPlayer.ram',
				'pls' => $site.'/radio/9772/Winamp.pls',
				'port' => '7136',
				'server' => $server,
				'radio' => $server.':7136',
				'url' => $site.'/translation-of-the-meaning-of-the-quran-in-swedish/',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_swedish'
			],
			111 => [
				'title' => 'Quran Recitation by Sheikh Abdulaziz Az-Zahrani',
				'title_ar' => 'تلاوة الشيخ عبد العزيز الزهراني',
				'asx' => $site.'/radio/9302/MediaPlayer.asx',
				'qtl' => $site.'/radio/9302/QuickTime.qtl',
				'ram' => $site.'/radio/9302/RealPlayer.ram',
				'pls' => $site.'/radio/9302/Winamp.pls',
				'port' => '7137',
				'server' => $server,
				'radio' => $server.':7137'
			],
			112 => [
				'title' => 'Quran Recitation by Sheikh Idris Abkar',
				'title_ar' => 'تلاوة الشيخ إدريس أبكر',
				'asx' => $site.'/radio/9300/MediaPlayer.asx',
				'qtl' => $site.'/radio/9300/QuickTime.qtl',
				'ram' => $site.'/radio/9300/RealPlayer.ram',
				'pls' => $site.'/radio/9300/Winamp.pls',
				'port' => '7138',
				'server' => $server,
				'radio' => $server.':7138'
			],
			113 => [
				'title' => 'Quran Recitation by Sheikh Abdulwali Al-Arkani',
				'title_ar' => 'تلاوة الشيخ عبد الولي الأركاني',
				'asx' => $site.'/radio/9304/MediaPlayer.asx',
				'qtl' => $site.'/radio/9304/QuickTime.qtl',
				'ram' => $site.'/radio/9304/RealPlayer.ram',
				'pls' => $site.'/radio/9304/Winamp.pls',
				'port' => '7139',
				'server' => $server,
				'radio' => $server.':7139'
			],
			114 => [
				'title' => 'Quran Recitation by Sheikh Fahd Al-Kandari',
				'title_ar' => 'تلاوة الشيخ فهد الكندري',
				'asx' => $site.'/radio/9306/MediaPlayer.asx',
				'qtl' => $site.'/radio/9306/QuickTime.qtl',
				'ram' => $site.'/radio/9306/RealPlayer.ram',
				'pls' => $site.'/radio/9306/Winamp.pls',
				'port' => '7140',
				'server' => $server,
				'radio' => $server.':7140'
			],
			115 => [
				'title' => 'Al-Mushaf Al-Mu`allim by Sheikh Muhammad Siddiq Al-Minshawi',
				'title_ar' => 'تلاوة الشيخ محمد صديق المنشاوي - المعلم',
				'asx' => $site.'/radio/9308/MediaPlayer.asx',
				'qtl' => $site.'/radio/9308/QuickTime.qtl',
				'ram' => $site.'/radio/9308/RealPlayer.ram',
				'pls' => $site.'/radio/9308/Winamp.pls',
				'port' => '7141',
				'server' => $server,
				'radio' => $server.':7141'
			],
			116 => [
				'title' => 'Mabahith fi Ulum al-Quran',
				'title_ar' => 'مباحث في علوم القرآن',
				'asx' => $site.'/radio/9310/MediaPlayer.asx',
				'qtl' => $site.'/radio/9310/QuickTime.qtl',
				'ram' => $site.'/radio/9310/RealPlayer.ram',
				'pls' => $site.'/radio/9310/Winamp.pls',
				'port' => '7146',
				'server' => $server,
				'radio' => $server.':7146'
			],
			117 => [
				'title' => 'Funun al-Afnan fi Ajaib Ulum al-Quran',
				'title_ar' => 'فنون الأفنان في عجائب علوم القرآن',
				'asx' => $site.'/radio/9312/MediaPlayer.asx',
				'qtl' => $site.'/radio/9312/QuickTime.qtl',
				'ram' => $site.'/radio/9312/RealPlayer.ram',
				'pls' => $site.'/radio/9312/Winamp.pls',
				'port' => '7145',
				'server' => $server,
				'radio' => $server.':7145'
			],
			118 => [
				'title' => 'Ghayat al-Mureed fi Ilm al-Tajweed',
				'title_ar' => 'غاية المريد في علم التجويد',
				'asx' => $site.'/radio/9314/MediaPlayer.asx',
				'qtl' => $site.'/radio/9314/QuickTime.qtl',
				'ram' => $site.'/radio/9314/RealPlayer.ram',
				'pls' => $site.'/radio/9314/Winamp.pls',
				'port' => '7144',
				'server' => $server,
				'radio' => $server.':7144'
			],
			119 => [
				'title' => 'Al-Ameed fi Ilm al-Tajweed',
				'title_ar' => 'العميد في علم التجويد',
				'asx' => $site.'/radio/9316/MediaPlayer.asx',
				'qtl' => $site.'/radio/9316/QuickTime.qtl',
				'ram' => $site.'/radio/9316/RealPlayer.ram',
				'pls' => $site.'/radio/9316/Winamp.pls',
				'port' => '7143',
				'server' => $server,
				'radio' => $server.':7143'
			],
			120 => [
				'title' => 'Al-Tafseer al-Mawdui il-ayat al-Tawheed fi al-Quran',
				'title_ar' => 'إذاعة التفسير الموضوعي لآيات التوحيد في القرآن',
				'asx' => $site.'/radio/9318/MediaPlayer.asx',
				'qtl' => $site.'/radio/9318/QuickTime.qtl',
				'ram' => $site.'/radio/9318/RealPlayer.ram',
				'pls' => $site.'/radio/9318/Winamp.pls',
				'port' => '7142',
				'server' => $server,
				'radio' => $server.':7142'
			],
			121 => [
				'title' => 'Quran Recitation by Sheikh Shaya At-Tamimi',
				'title_ar' => 'تلاوة الشيخ شايع التميمي',
				'asx' => $site.'/radio/9320/MediaPlayer.asx',
				'qtl' => $site.'/radio/9320/QuickTime.qtl',
				'ram' => $site.'/radio/9320/RealPlayer.ram',
				'pls' => $site.'/radio/9320/Winamp.pls',
				'port' => '7152',
				'server' => $server,
				'radio' => $server.':7152'
			],
			122 => [
				'title' => 'Shams Al-Islam Radio',
				'title_ar' => 'إذاعة شمس الإسلام (تفسير بالإنجليزية)',
				'asx' => $site.'/radio/9322/MediaPlayer.asx',
				'qtl' => $site.'/radio/9322/QuickTime.qtl',
				'ram' => $site.'/radio/9322/RealPlayer.ram',
				'pls' => $site.'/radio/9322/Winamp.pls',
				'port' => '7016',
				'server' => $server,
				'radio' => $server.':7016'
			],
			123 => [
				'title' => 'Translation of the Quran in Turkish',
				'title_ar' => 'ترجمة القرآن الكريم بالتركية',
				'rss' => $site.'/podcast/Turkish/Translation_of_the_Quran_in_Turkish.rss',
				'podcast' => 'https://podcasts.apple.com/kw/podcast/translation-of-the-quran-in-turkish/id1495774661',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjkzMjQvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Turkish/Turkish.txt',
				'asx' => $site.'/radio/9324/MediaPlayer.asx',
				'qtl' => $site.'/radio/9324/QuickTime.qtl',
				'ram' => $site.'/radio/9324/RealPlayer.ram',
				'pls' => $site.'/radio/9324/Winamp.pls',
				'port' => '7151',
				'server' => $server,
				'radio' => $server.':7151',
				'url' => $site.'/index.php?moshaf=16&id=16',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation_of_the_quran_in_turkish'
			],
			124 => [
				'title' => 'Translation of the Quran in Spanish (of Latin America)',
				'title_ar' => 'ترجمة القرآن الكريم باللاتينية',
				'rss' => $site.'/podcast/Latin/Translation_of_the_Quran_in_spanish_of_latin_america.rss',
				'podcast' => 'https://podcasts.apple.com/kw/podcast/translation-of-the-quran-in-latin/id1495774709',
				'google_podcast' => 'https://podcasts.google.com/feed/aHR0cHM6Ly9xdXJhbi5jb20ua3cvcG9kY2FzdHMvcnNzL3dlc3Rlcm4tcG9kY2FzdC5yc3M/episode/aHR0cDovL3NlcnZlcjIucXVyYWFuLnVzOjkzMjgvOyoubXAz?sa=X&ved=0CA0QkfYCahcKEwi4nY-MyLv4AhUAAAAAHQAAAAAQAQ',
				'txt' => $site.'/txt/Latin/Latin.txt',
				'asx' => $site.'/radio/7041/MediaPlayer.asx',
				'qtl' => $site.'/radio/7041/QuickTime.qtl',
				'ram' => $site.'/radio/7041/RealPlayer.ram',
				'pls' => $site.'/radio/7041/Winamp.pls',
				'port' => '7041',
				'server' => $server,
				'radio' => $server.':7041',
				'url' => $site.'/index.php?moshaf=16&id=16'
			],
			125 => [
				'title' => 'Quran Recitation by Sheikh Osama bin Mohammed Abu Zaid',
				'title_ar' => 'تلاوة الشيخ أسامة بن محمد أبو زيد',
				'asx' => $site.'/radio/7040/MediaPlayer.asx',
				'qtl' => $site.'/radio/7040/QuickTime.qtl',
				'ram' => $site.'/radio/7040/RealPlayer.ram',
				'pls' => $site.'/radio/7040/Winamp.pls',
				'port' => '7040',
				'server' => $server,
				'radio' => $server.':7040'
			],
			126 => [
				'title' => 'Quran Recitation by Sheikh Imad Zuhair Hafez',
				'title_ar' => 'تلاوة الشيخ زهير حافظ',
				'asx' => $site.'/radio/7039/MediaPlayer.asx',
				'qtl' => $site.'/radio/7039/QuickTime.qtl',
				'ram' => $site.'/radio/7039/RealPlayer.ram',
				'pls' => $site.'/radio/7039/Winamp.pls',
				'port' => '7039',
				'server' => $server,
				'radio' => $server.':7039'
			],
			127 => [
				'title' => 'Tafsir Al-muyassar - Mohammad Ayyub',
				'title_ar' => 'التفسير الميسر مصحوبًا بتلاوة الشيخ محمد أيوب',
				'asx' => $site.'/radio/7042/MediaPlayer.asx',
				'qtl' => $site.'/radio/7042/QuickTime.qtl',
				'ram' => $site.'/radio/7042/RealPlayer.ram',
				'pls' => $site.'/radio/7042/Winamp.pls',
				'port' => '7042',
				'server' => $server,
				'radio' => $server.':7042'
			],
			128 => [
				'title' => 'Al-Mushaf Al-Muallim with English Translation',
				'title_ar' => 'إذاعة المصحف المعلم باللغة بالإنجليزية',
				'asx' => $site.'/radio/7045/MediaPlayer.asx',
				'qtl' => $site.'/radio/7045/QuickTime.qtl',
				'ram' => $site.'/radio/7045/RealPlayer.ram',
				'pls' => $site.'/radio/7045/Winamp.pls',
				'port' => '7045',
				'server' => $server,
				'radio' => $server.':7045',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/quran_in_english_read_version_children'
			],
			129 => [
				'title' => 'Al-Mushaf Al-Muallim with French Translation',
				'title_ar' => 'إذاعة المصحف المعلم باللغة بالفرنسية',
				'asx' => $site.'/radio/7046/MediaPlayer.asx',
				'qtl' => $site.'/radio/7046/QuickTime.qtl',
				'ram' => $site.'/radio/7046/RealPlayer.ram',
				'pls' => $site.'/radio/7046/Winamp.pls',
				'port' => '7046',
				'server' => $server,
				'radio' => $server.':7046',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/quran_in_french_read_version_children'
			],
			130 => [
				'title' => 'Al-Mushaf Al-Muallim with Spain Translation',
				'title_ar' => 'إذاعة المصحف المعلم باللغة بالإسبانية',
				'asx' => $site.'/radio/7048/MediaPlayer.asx',
				'qtl' => $site.'/radio/7048/QuickTime.qtl',
				'ram' => $site.'/radio/7048/RealPlayer.ram',
				'pls' => $site.'/radio/7048/Winamp.pls',
				'port' => '7048',
				'server' => $server,
				'radio' => $server.':7048',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/quran-in-spanish-read-version-children'
			],
			131 => [
				'title' => 'Al-Mushaf Al-Muallim with Latin Translation',
				'title_ar' => 'إذاعة المصحف المعلم باللغة الإسبانية (لهجة دول أمريكا اللاتينية)',
				'asx' => $site.'/radio/7047/MediaPlayer.asx',
				'qtl' => $site.'/radio/7047/QuickTime.qtl',
				'ram' => $site.'/radio/7047/RealPlayer.ram',
				'pls' => $site.'/radio/7047/Winamp.pls',
				'port' => '7047',
				'server' => $server,
				'radio' => $server.':7047',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/quran_in_latin_version_children'
			],
			132 => [
				'title' => 'Translation of the Quran in Maranao',
				'title_ar' => 'ترجمة القرآن الكريم بالفلبينية (ماراناو)',
				'txt' => '',
				'asx' => $site.'/radio/7044/MediaPlayer.asx',
				'qtl' => $site.'/radio/7044/QuickTime.qtl',
				'ram' => $site.'/radio/7044/RealPlayer.ram',
				'pls' => $site.'/radio/7044/Winamp.pls',
				'port' => '7044',
				'server' => $server,
				'radio' => $server.':7044',
				'soundcloud' => 'https://soundcloud.com/edckwt/sets/translation-of-the-quran-in-maranao'
			]
		];
		return $radios;
	}

	public function play_audio($f, $id=''){
		$html = '<div class="quran-audio"'. ( empty($id) ? '' : ' id="quran-audio-'.$id.'"' ) .'>';
		$html .= '<audio class="audio-player" controls autoplay'. ( empty($id) ? '' : ' id="audio-'.$id.'"' ) .'>'; //autoplay
		$html .= '<source src="'.$f.'" type="audio/mp3">';
		$html .= '</audio>';
		$html .= '</div>';
		return $html;
	}

	public function quick_links(){
		if( $this->show_quick_links ){
			$html = '<div class="quick-links position-fixed right-0 align-y-center zIndex-99 bg-white">';
			$html .= '<p class="ql-p mb-0"><i class="fa-solid fa-gear ql-fs-icon"></i> <span class="ql-span">'.$this->lang('setting').'</span></p>';
			$html .= '<div class="ql-div">';

			if( empty($this->action()) ){
				$html .= '<p class="mb-2">'.$this->lang('filter').'</p>';
				foreach ($this->radio_cargories() as $key => $value) {
					$html .= '<div class="form-check mb-1">';
					$html .= '<input class="form-check-input filter_categories" type="checkbox" value="1" id="filter_'.$key.'" data-class="'.$key.'" checked>';
					$html .= '<label class="form-check-label" for="filter_'.$key.'">'.$this->lang($key).'</label>';
					$html .= '</div>';
				}
			}

			$html .= '<div class="form-check mt-3">';
			$html .= '<input class="form-check-input" type="checkbox" value="1" id="hideHeader">';
			$html .= '<label class="form-check-label" for="hideHeader">'.$this->lang('hide_header').'</label>';
			$html .= '</div>';
			$html .= '<div class="form-check mt-1">';
			$html .= '<input class="form-check-input" type="checkbox" value="1" id="hideFooter">';
			$html .= '<label class="form-check-label" for="hideFooter">'.$this->lang('hide_footer').'</label>';
			$html .= '</div>';
			$html .= '<div class="form-check mt-1 mb-3">';
			$html .= '<input class="form-check-input" type="checkbox" value="1" id="darkMod">';
			$html .= '<label class="form-check-label" for="darkMod">'.$this->lang('dark_mod').'</label>';
			$html .= '</div>';

			$html .= '</div>';
			$html .= '</div>';
		}else{
			$html = '';
		}
		return $html;
	}
}
?>
